SystemOrganization addCategory: #ConfigurationOfFuel!

Object subclass: #ConfigurationOfFuel
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfFuel'!

!ConfigurationOfFuel commentStamp: '<historical>' prior: 0!
Fuel is a general-purpose object serialization framework.

See more information in our website:
http://rmod.lille.inria.fr/web/pier/software/Fuel/!

!ConfigurationOfFuel class methodsFor: 'development support' stamp: 'MartinDias 2/19/2011 03:09'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfFuel class methodsFor: 'private' stamp: 'MaxLeske 3/6/2016 16:45'!
addHacks
	"Simply load FuelPlatform. The class side initialization will take care of installing
	extensions and hacks"
	(Smalltalk hasClassNamed: #FLPlatform) ifTrue: [ ^ self ].
	
	Gofer it
		package: 'FuelPlatform';
		url: 'http://smalltalkhub.com/mc/Pharo/Fuel/main';
		load! !

!ConfigurationOfFuel class methodsFor: 'private' stamp: 'MartinDias 2/19/2011 03:09'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfFuel class methodsFor: 'private' stamp: 'MartinDias 2/19/2011 03:09'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfFuel class methodsFor: 'private' stamp: 'foo 2/16/2014 17:22'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemtalksystems.com/ss/metacello/' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfFuel class methodsFor: 'metacello tool support' stamp: 'MartinDias 2/19/2011 03:09'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfFuel class methodsFor: 'loading' stamp: 'MartinDias 2/19/2011 03:09'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfFuel class methodsFor: 'loading' stamp: 'MartinDias 2/19/2011 03:09'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfFuel class methodsFor: 'loading' stamp: 'MarianoMartinezPeck 5/2/2012 21:40'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load: 'DevelopmentGroup'! !

!ConfigurationOfFuel class methodsFor: 'accessing' stamp: 'MaxLeske 2/19/2016 11:28'!
project
	^ self new project! !

!ConfigurationOfFuel class methodsFor: 'development support' stamp: 'MartinDias 2/19/2011 03:09'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfFuel methodsFor: 'private' stamp: 'MaxLeske 2/20/2016 14:29'!
addPostloadHacks
	"Simply perform #addHacks again. We've now loaded classes that weren't
	there before and some of those also need extensions" 
	(Smalltalk at: #FLPlatform) current addHacks! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MartinDias 8/5/2013 14:02'!
baseline10: spec 
        <version: '1.0-baseline'>
        
        spec for: #pharo do: [
                spec blessing: #baseline.
                self fuelRepository: spec.    

                spec 
                        package: 'Fuel';
                        package: 'FuelBenchmarks' with: [ spec requires: 'Fuel' ];
                        package: 'FuelBenchmarksMC2' with: [ 
					spec 
						requires: 'FuelBenchmarks';
						requires: 'Monticello2' ];
                        package: 'FuelBenchmarksMagma' with: [ 
					spec
						requires: 'FuelBenchmarks';
						requires: 'Magma' ].

                spec
				project: 'Monticello2' with: [
				spec
					className: 'ConfigurationOfMonticello2';
					loads: #('DEFAULT');
					file: 'ConfigurationOfMonticello2';
					repository: 'http://source.wiresong.ca/mc/' ].
                spec
				project: 'Magma' with: [
				spec
					className: 'ConfigurationOfMagma';
					loads: #('default');
					file: 'ConfigurationOfMagma';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
                        group: 'default' with: #('Fuel' 'Benchmarks' );
                        group: 'Core' with: #('Fuel');
                        group: 'Benchmarks' with: #('FuelBenchmarks');
				group: 'MC2Benchmarks' with: #('FuelBenchmarksMC2');
				group: 'MagmaBenchmarks' with: #('FuelBenchmarksMagma') ].! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MartinDias 8/5/2013 14:02'!
baseline11: spec 
        <version: '1.1-baseline'>
        
        spec for: #pharo do: [
                spec blessing: #baseline.
                self fuelRepository: spec.    

                spec 
                        package: 'Fuel';
                        package: 'FuelBenchmarks' with: [ spec requires: 'Fuel' ];
                        package: 'FuelBenchmarksMC2' with: [ 
					spec 
						requires: 'FuelBenchmarks';
						requires: 'Monticello2' ];
                        package: 'FuelBenchmarksMagma' with: [ 
					spec
						requires: 'FuelBenchmarks';
						requires: 'Magma' ];
                        package: 'FuelProgressUpdate' with: [ spec requires: 'Fuel' ].


                spec
				project: 'Monticello2' with: [
				spec
					className: 'ConfigurationOfMonticello2';
					loads: #('DEFAULT');
					file: 'ConfigurationOfMonticello2';
					repository: 'http://source.wiresong.ca/mc/' ].
                spec
				project: 'Magma' with: [
				spec
					className: 'ConfigurationOfMagma';
					loads: #('default');
					file: 'ConfigurationOfMagma';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
                        group: 'default' with: #('Fuel' 'Benchmarks' );
                        group: 'Core' with: #('Fuel');
                        group: 'CoreWithProgressBar' with: #('Fuel' 'FuelProgressUpdate');
                        group: 'Benchmarks' with: #('FuelBenchmarks');
				group: 'MC2Benchmarks' with: #('FuelBenchmarksMC2');
				group: 'MagmaBenchmarks' with: #('FuelBenchmarksMagma') ].! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MartinDias 8/5/2013 14:02'!
baseline12: spec 
        <version: '1.2-baseline'>
        
        spec for: #pharo do: [
                spec blessing: #baseline.
                self fuelRepository: spec.    

                spec 
                        package: 'Fuel';
                        package: 'FuelBenchmarks' with: [ spec requires: 'Fuel' ];
                        package: 'FuelBenchmarksMC2' with: [ 
					spec 
						requires: 'FuelBenchmarks';
						requires: 'Monticello2' ];
                        package: 'FuelBenchmarksMagma' with: [ 
					spec
						requires: 'FuelBenchmarks';
						requires: 'Magma' ];
                        package: 'FuelProgressUpdate' with: [ spec requires: 'Fuel' ];
                        package: 'FuelContainer' with: [ spec requires: 'Fuel' ];
				package: 'FuelTests' with: [ spec requires: 'Fuel' ].


                spec
				project: 'Monticello2' with: [
				spec
					className: 'ConfigurationOfMonticello2';
					loads: #('DEFAULT');
					file: 'ConfigurationOfMonticello2';
					repository: 'http://source.wiresong.ca/mc/' ].
                spec
				project: 'Magma' with: [
				spec
					className: 'ConfigurationOfMagma';
					loads: #('default');
					file: 'ConfigurationOfMagma';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
                        group: 'default' with: #('Fuel' 'Tests' 'Benchmarks' );
                        group: 'Core' with: #('Fuel');
                        group: 'CoreWithExtras' with: #('Fuel' 'FuelProgressUpdate' 'FuelContainer');
				group: 'Tests' with: #('FuelTests');
                        group: 'Benchmarks' with: #('FuelBenchmarks');
				group: 'MC2Benchmarks' with: #('FuelBenchmarksMC2');
				group: 'MagmaBenchmarks' with: #('FuelBenchmarksMagma') ].! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MartinDias 8/5/2013 14:02'!
baseline15: spec 
        <version: '1.5-baseline'>
        
        spec for: #pharo do: [
                spec blessing: #baseline.
                self fuelRepository: spec.    

                spec 
                        package: 'Fuel';
				package: 'FuelTests' with: [ spec requires: 'Fuel' ];
                        package: 'FuelProgressUpdate' with: [ spec requires: 'Fuel' ];
                        package: 'FuelContainer' with: [ spec requires: 'Fuel' ];
                        package: 'FuelBenchmarks' with: [ spec requires: #('Fuel' 'FuelTests') ];
                        package: 'FuelBenchmarksMagma' with: [ spec requires: #('FuelBenchmarks' 'MagmaBase') ];
                        package: 'FuelBenchmarksSIXX' with: [ spec requires: #('FuelBenchmarks' 'SIXX') ];
                        package: 'FuelBenchmarksStomp' with: [ spec requires: #('FuelBenchmarks' 'StOMP') ];
				package: 'FuelProgressUpdateBenchmarks' with: [ spec requires: #('FuelBenchmarks' 'FuelProgressUpdate') ];
                        package: 'FuelBenchmarksSRP' with: [ spec requires: #('FuelBenchmarks' 'SRP') ];
                        package: 'FuelBenchmarksEsAndEm' with: [ spec requires: #('FuelBenchmarks' 'EsAndEm') ];
                        package: 'FuelLogo'.


                spec
				project: 'MagmaBase' with: [
				spec
					className: 'ConfigurationOfMaBase';
					loads: #('default');
					file: 'ConfigurationOfMaBase';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
				project: 'SIXX' with: [
				spec
					className: 'ConfigurationOfSIXX';
					loads: #('default');
					file: 'ConfigurationOfSIXX';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
				
		     spec
				project: 'StOMP' with: [
				spec
					className: 'ConfigurationOfStOMP';
					loads: #('default');
					file: 'ConfigurationOfStOMP';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

			spec
				package: 'SRP' with: [ spec repository: 'http://www.squeaksource.com/SRP' ].

			spec
				package: 'EsAndEm' with: [ spec repository: 'http://source.wiresong.ca/mc' ].

			spec
				group: 'default' with: #('Core' 'Tests' 'Benchmarks');
				group: 'Core' with: #('Fuel');
				group: 'CoreWithExtras' with: #('Fuel' 'FuelProgressUpdate' 'FuelContainer');
				group: 'Tests' with: #('FuelTests');
				group: 'Benchmarks' with: #('FuelBenchmarks');
				group: 'BenchmarksSIXX' with: #('Benchmarks' 'FuelBenchmarksSIXX');
				group: 'BenchmarksAllBinarySerializers' with: #('Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelBenchmarksStomp' 'FuelBenchmarksMagma' 'FuelBenchmarksSRP' 'FuelBenchmarksEsAndEm') ].! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MartinDias 8/5/2013 14:03'!
baseline16: spec 
        <version: '1.6-baseline'>
        
        spec for: #pharo do: [
                spec blessing: #baseline.
                self fuelRepository: spec.    

                spec 
                        package: 'Fuel';
				package: 'FuelTests' with: [ spec requires: 'Fuel' ];
                        package: 'FuelProgressUpdate' with: [ spec requires: 'Fuel' ];
                        package: 'FuelContainer' with: [ spec requires: 'Fuel' ];
                        package: 'FuelBenchmarks' with: [ spec requires: #('Fuel' 'FuelTests') ];
                        package: 'FuelBenchmarksMagma' with: [ spec requires: #('FuelBenchmarks' 'MagmaBase') ];
                        package: 'FuelBenchmarksSIXX' with: [ spec requires: #('FuelBenchmarks' 'SIXX') ];
                        package: 'FuelBenchmarksStomp' with: [ spec requires: #('FuelBenchmarks' 'StOMP') ];
				package: 'FuelProgressUpdateBenchmarks' with: [ spec requires: #('FuelBenchmarks' 'FuelProgressUpdate') ];
                        package: 'FuelBenchmarksSRP' with: [ spec requires: #('FuelBenchmarks' 'SRP') ];
                        package: 'FuelBenchmarksEsAndEm' with: [ spec requires: #('FuelBenchmarks' 'EsAndEm') ];
                        package: 'FuelLogo';
				package: 'FuelExamples' with: [ spec requires: 'FuelProgressUpdate'];
				package: 'FuelPackageLoader' with: [ spec requires: 'Fuel' ];	
				package: 'FuelPackageLoaderTests' with: [ spec requires: #('FuelPackageLoader' 'FuelTests' ) ].	

                spec
				project: 'MagmaBase' with: [
				spec
					className: 'ConfigurationOfMaBase';
					loads: #('default');
					file: 'ConfigurationOfMaBase';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
				project: 'SIXX' with: [
				spec
					className: 'ConfigurationOfSIXX';
					loads: #('default');
					file: 'ConfigurationOfSIXX';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
				
		     spec
				project: 'StOMP' with: [
				spec
					className: 'ConfigurationOfStOMP';
					loads: #('default');
					file: 'ConfigurationOfStOMP';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

			spec
				package: 'SRP' with: [ spec repository: 'http://www.squeaksource.com/SRP' ].

			spec
				package: 'EsAndEm' with: [ spec repository: 'http://source.wiresong.ca/mc' ].

			spec
				group: 'default' with: #('Core' 'Tests' 'Benchmarks' 'Examples');
				group: 'Core' with: #('Fuel');
				group: 'CoreWithExtras' with: #('Fuel' 'FuelProgressUpdate' 'FuelContainer');
				group: 'Tests' with: #('FuelTests');
				group: 'Examples' with: #('FuelExamples');
				group: 'PackageLoader' with: #('FuelPackageLoader');
				group: 'PackageLoaderWithTests' with: #('FuelPackageLoader' 'FuelPackageLoaderTests');
				group: 'Benchmarks' with: #('FuelBenchmarks');
				group: 'BenchmarksSIXX' with: #('Benchmarks' 'FuelBenchmarksSIXX');
				group: 'BenchmarksAllBinarySerializers' with: #('Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelBenchmarksStomp' 'FuelBenchmarksMagma' 'FuelBenchmarksSRP' 'FuelBenchmarksEsAndEm') ].! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MartinDias 8/5/2013 14:03'!
baseline17: spec 
        <version: '1.7-baseline'>
        
        spec for: #pharo do: [
                spec blessing: #baseline.
                self fuelRepository: spec.    

                spec 
                        package: 'Fuel';
				package: 'FuelTests' with: [ spec requires: 'Fuel' ];
                        package: 'FuelProgressUpdate' with: [ spec requires: 'Fuel' ];
                        package: 'FuelContainer' with: [ spec requires: 'Fuel' ];
                        package: 'FuelBenchmarks' with: [ spec requires: #('Fuel' 'FuelTests') ];
                        package: 'FuelBenchmarksMagma' with: [ spec requires: #('FuelBenchmarks' 'MagmaBase') ];
                        package: 'FuelBenchmarksSIXX' with: [ spec requires: #('FuelBenchmarks' 'SIXX') ];
                        package: 'FuelBenchmarksStomp' with: [ spec requires: #('FuelBenchmarks' 'StOMP') ];
				package: 'FuelProgressUpdateBenchmarks' with: [ spec requires: #('FuelBenchmarks' 'FuelProgressUpdate') ];
                        package: 'FuelBenchmarksSRP' with: [ spec requires: #('FuelBenchmarks' 'SRP') ];
                        package: 'FuelBenchmarksEsAndEm' with: [ spec requires: #('FuelBenchmarks' 'EsAndEm') ];
                        package: 'FuelLogo';
				package: 'FuelExamples' with: [ spec requires: 'FuelProgressUpdate'];
				package: 'FuelPackageLoader' with: [ spec requires: 'Fuel' ];	
				package: 'FuelPackageLoaderTests' with: [ spec requires: #('FuelPackageLoader' 'FuelTests' ) ].	

                spec
				project: 'MagmaBase' with: [
				spec
					className: 'ConfigurationOfMaBase';
					loads: #('default');
					file: 'ConfigurationOfMaBase';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
				project: 'SIXX' with: [
				spec
					className: 'ConfigurationOfSIXX';
					loads: #('default');
					file: 'ConfigurationOfSIXX';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
				
		     spec
				project: 'StOMP' with: [
				spec
					className: 'ConfigurationOfStOMP';
					loads: #('default');
					file: 'ConfigurationOfStOMP';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

			spec
				package: 'SRP' with: [ spec repository: 'http://www.squeaksource.com/SRP' ].

			spec
				package: 'EsAndEm' with: [ spec repository: 'http://source.wiresong.ca/mc' ].

			spec
				group: 'default' with: #('Core' 'Tests' 'Benchmarks' 'Examples');
				group: 'Core' with: #('Fuel');
				group: 'CoreWithExtras' with: #('Fuel' 'FuelProgressUpdate');
				group: 'Tests' with: #('FuelTests');
				group: 'Examples' with: #('FuelExamples');
				group: 'PackageLoader' with: #('FuelPackageLoader');
				group: 'PackageLoaderWithTests' with: #('FuelPackageLoader' 'FuelPackageLoaderTests');
				group: 'Benchmarks' with: #('FuelBenchmarks');
				group: 'BenchmarksSIXX' with: #('Benchmarks' 'FuelBenchmarksSIXX');
				group: 'BenchmarksAllBinarySerializers' with: #('Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelBenchmarksStomp' 'FuelBenchmarksMagma' 'FuelBenchmarksSRP' 'FuelBenchmarksEsAndEm');
				group: 'DevelopmentGroup' with: #('CoreWithExtras' 'Tests' 'Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelLogo' 'Examples' 'PackageLoaderWithTests' 'FuelContainer') ].
			
			
			
	spec for: #'pharo1.2.x' do: [
	
		spec 
			package: 'FuelCompatibilityBeforePharo13' with: [
				spec requires: #( 'Fuel' )].
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo13').
		
	].

	spec for: #'pharo1.1.x' do: [
	
		spec 
			package: 'FuelCompatibilityBeforePharo12' with: [
				spec requires: #( 'FuelCompatibilityBeforePharo13' )].
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo12').
		
	].! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MartinDias 8/5/2013 14:06'!
baseline181: spec 
        <version: '1.8.1-baseline'>
        
	spec for: #squeakCommon do: [
		
		spec blessing: #baseline.
		self fuelRepository: spec.    

		spec 
			package: 'Fuel';
			package: 'FuelTests' with: [ spec requires: 'Fuel' ];
			package: 'FuelDebug' with: [ spec requires: 'Fuel' ];
			package: 'FuelUtilities';
			package: 'FuelProgressUpdate' with: [ spec requires: 'Fuel' ];
			package: 'FuelBenchmarks' with: [ spec requires: #('Fuel' 'FuelTests' 'FuelUtilities') ];
			package: 'FuelCompression'  with: [ spec requires: #('Fuel' 'FuelTests' ) ].
							
		spec
			package: 'FuelCompatibilityBeforeSqueak42' with: [ spec requires: #( 'FuelCompatibilityBeforeSqueak44' ) ];	
			package: 'FuelCompatibilityBeforeSqueak44' with: [ spec requires: #( 'FuelCompatibilityBeforeSqueak45' ) ];	
			package: 'FuelCompatibilityBeforeSqueak45' with: [ spec requires: #( 'Fuel' ) ];
			
			package: 'FuelTestsCompatibilityBeforeSqueak42' with: [ spec requires: #( 'FuelTestsCompatibilityBeforeSqueak44' ) ];
			package: 'FuelTestsCompatibilityBeforeSqueak44' with: [ spec requires: #( 'FuelTestsCompatibilityBeforeSqueak45' ) ];
			package: 'FuelTestsCompatibilityBeforeSqueak45' with: [ spec requires: #( 'FuelTests' ) ].
			
		spec
			package: 'FuelCompatibilityBeforePharo12' with: [ spec requires: #( 'FuelCompatibilityBeforePharo13' ) ];
			package: 'FuelCompatibilityBeforePharo13' with: [ spec requires: #( 'FuelCompatibilityBeforePharo14' ) ];
			package: 'FuelCompatibilityBeforePharo14' with: [ spec requires: #( 'FuelCompatibilityBeforePharo20' ) ];
			package: 'FuelCompatibilityBeforePharo20' with: [ spec requires: #( 'FuelCompatibilityBeforePharo21' ) ];
			package: 'FuelCompatibilityBeforePharo21' with: [ spec requires: #( 'Fuel' ) ];
			
			package: 'FuelTestsCompatibilityBeforePharo21' with: [ spec requires: #( 'FuelTests' ) ].
			
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Fuel');
			group: 'CoreWithExtras' with: #('Core' 'FuelProgressUpdate' 'FuelCompression');
			group: 'Tests' with: #('FuelTests');
			group: 'Benchmarks' with: #('FuelBenchmarks').
	].

	spec for: #pharo do: [
              
		spec
			package: 'FuelBenchmarksMagma' with: [ spec requires: #('FuelBenchmarks' 'MagmaBase') ];
                 	package: 'FuelBenchmarksSIXX' with: [ spec requires: #('FuelBenchmarks' 'SIXX') ];
                 	package: 'FuelBenchmarksStomp' with: [ spec requires: #('FuelBenchmarks' 'StOMP') ];
			package: 'FuelProgressUpdateBenchmarks' with: [ spec requires: #('FuelBenchmarks' 'FuelProgressUpdate') ];
                	package: 'FuelBenchmarksSRP' with: [ spec requires: #('FuelBenchmarks' 'SRP') ];
                	package: 'FuelBenchmarksEsAndEm' with: [ spec requires: #('FuelBenchmarks' 'EsAndEm') ];
			package: 'FuelPackageLoader' with: [ spec requires: #('Fuel' 'FuelMetalevel' ) ];	
			package: 'FuelPackageLoaderMetacello' with: [ spec requires: #( 'FuelPackageLoader' ) ];	
			package: 'FuelPackageLoaderTests' with: [ spec requires: #('FuelPackageLoader' 'FuelTests' )];
			package: 'FuelPreview' with: [ spec requires: #( 'FuelDebug' 'Roassal')];
			package: 'FuelMetalevel' with: [ spec requires: #( 'Fuel' )];
			package: 'FuelMetalevelTests' with: [ spec requires: #('FuelMetalevel' 'FuelTests' )].
		
                spec
				project: 'MagmaBase' with: [
				spec
					className: 'ConfigurationOfMaBase';
					loads: #('default');
					file: 'ConfigurationOfMaBase';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
				project: 'SIXX' with: [
				spec
					className: 'ConfigurationOfSIXX';
					loads: #('default');
					file: 'ConfigurationOfSIXX';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
				
		     spec
				project: 'StOMP' with: [
				spec
					className: 'ConfigurationOfStOMP';
					loads: #('default');
					file: 'ConfigurationOfStOMP';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
				project: 'Roassal' with: [
				spec
					className: 'ConfigurationOfRoassal';
					loads: #('default');
					file: 'ConfigurationOfRoassal';
					repository: 'http://www.squeaksource.com/Roassal' ].
				
		    spec
				project: 'FileSystem' with: [
				spec
					className: 'ConfigurationOfFilesystem';
					loads: #('default');
					file: 'ConfigurationOfFilesystem';
					repository: 'http://www.squeaksource.com/fs' ].

			spec
				package: 'SRP' with: [ spec repository: 'http://www.squeaksource.com/SRP' ].

			spec
				package: 'EsAndEm' with: [ spec repository: 'http://source.wiresong.ca/mc' ].

			spec
				group: 'CoreWithExtras' with: #('Core'  'FuelMetalevel' 'FuelProgressUpdate' 'FuelCompression');
				group: 'Tests' with: #('FuelTests' );
				group: 'PackageLoader' with: #('FuelPackageLoader' 'FuelPackageLoaderMetacello');
				group: 'PackageLoaderWithTests' with: #('PackageLoader' 'FuelPackageLoaderTests');
				group: 'BenchmarksSIXX' with: #('Benchmarks' 'FuelBenchmarksSIXX');
				group: 'BenchmarksAllBinarySerializers' with: #('Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelBenchmarksStomp' 'FuelBenchmarksMagma' 'FuelBenchmarksSRP' 'FuelBenchmarksEsAndEm');
				group: 'DevelopmentGroup' with: #('CoreWithExtras' 'Tests' 'FuelMetalevelTests' 'Benchmarks' 'FuelProgressUpdateBenchmarks' PackageLoader 'PackageLoaderWithTests' 'FuelDebug' 'FuelUtilities').
				
	].
		
	
	spec for: #'pharo2.0.x' do: [
		
		spec	
			package: 'FuelFileSystem';
			package: 'FuelFileSystemTests' with: [ spec requires: #('FuelTests')];
			package: 'FuelCommandLineHandler'.
								
		spec group: 'DevelopmentGroup' with: #('FuelFileSystem' 'FuelFileSystemTests' 'FuelCommandLineHandler').
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo21').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo21').
		
	].
	
	
	spec for: #'pharo1.4.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo20').
		
	].
	
	
	spec for: #'pharo1.3.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo14').
		
	].

			
			
	spec for: #'pharo1.2.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo13').
		
	].

	spec for: #'pharo1.1.x' do: [
	
		spec 
			package: 'Fuel' with: [ spec preLoadDoIt: #preLoadInPharo11].
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo12').
		
	].

	spec for: #'squeak4.1.x' do: [
			
		spec group: 'Core' with: #('FuelCompatibilityBeforeSqueak42').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak42').
			
	].

	spec for: #'squeak4.2.x' do: [
			
		spec group: 'Core' with: #('FuelCompatibilityBeforeSqueak44').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak44').
			
	].

	spec for: #'squeak4.3.x' do: [
			
		spec group: 'Core' with: #('FuelCompatibilityBeforeSqueak44').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak44').
			
	].

	spec for: #'squeak4.4.x' do: [
			
		spec group: 'Core' with: #('FuelCompatibilityBeforeSqueak45').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak45').
			
	].! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MartinDias 8/5/2013 14:06'!
baseline182: spec 
        <version: '1.8.2-baseline'>
        
	spec for: #squeakCommon do: [
		
		spec blessing: #baseline.
		self fuelRepository: spec.    

		spec 
			package: 'Fuel';
			package: 'FuelTests' with: [ spec requires: 'Fuel' ];
			package: 'FuelDebug' with: [ spec requires: 'Fuel' ];
			package: 'FuelUtilities';
			package: 'FuelProgressUpdate' with: [ spec requires: 'Fuel' ];
			package: 'FuelBenchmarks' with: [ spec requires: #('Fuel' 'FuelTests' 'FuelUtilities') ];
			package: 'FuelCompression'  with: [ spec requires: #('Fuel' 'FuelTests' ) ].
							
		spec
			package: 'FuelCompatibilityBeforeSqueak42' with: [ spec requires: #( 'FuelCompatibilityBeforeSqueak44' ) ];	
			package: 'FuelCompatibilityBeforeSqueak44' with: [ spec requires: #( 'FuelCompatibilityBeforeSqueak45' ) ];	
			package: 'FuelCompatibilityBeforeSqueak45' with: [ spec requires: #( 'Fuel' ) ];
			
			package: 'FuelTestsCompatibilityBeforeSqueak42' with: [ spec requires: #( 'FuelTestsCompatibilityBeforeSqueak44' ) ];
			package: 'FuelTestsCompatibilityBeforeSqueak44' with: [ spec requires: #( 'FuelTestsCompatibilityBeforeSqueak45' ) ];
			package: 'FuelTestsCompatibilityBeforeSqueak45' with: [ spec requires: #( 'FuelTests' ) ].
			
		spec
			package: 'FuelCompatibilityBeforePharo12' with: [ spec requires: #( 'FuelCompatibilityBeforePharo13' ) ];
			package: 'FuelCompatibilityBeforePharo13' with: [ spec requires: #( 'FuelCompatibilityBeforePharo14' ) ];
			package: 'FuelCompatibilityBeforePharo14' with: [ spec requires: #( 'FuelCompatibilityBeforePharo20' ) ];
			package: 'FuelCompatibilityBeforePharo20' with: [ spec requires: #( 'FuelCompatibilityBeforePharo21' ) ];
			package: 'FuelCompatibilityBeforePharo21' with: [ spec requires: #( 'Fuel' ) ];
			
			package: 'FuelTestsCompatibilityBeforePharo20' with: [ spec requires: #( 
				'FuelCompatibilityBeforePharo21' 
				'FuelTestsCompatibilityBeforePharo21' ) ];
			package: 'FuelTestsCompatibilityBeforePharo21' with: [ spec requires: #( 'FuelTests' ) ].
			
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Fuel');
			group: 'CoreWithExtras' with: #('Core' 'FuelProgressUpdate' 'FuelCompression');
			group: 'Tests' with: #('FuelTests');
			group: 'Benchmarks' with: #('FuelBenchmarks').
	].

	spec for: #pharo do: [
              
		spec
			package: 'FuelBenchmarksMagma' with: [ spec requires: #('FuelBenchmarks' 'MagmaBase') ];
                 	package: 'FuelBenchmarksSIXX' with: [ spec requires: #('FuelBenchmarks' 'SIXX') ];
                 	package: 'FuelBenchmarksStomp' with: [ spec requires: #('FuelBenchmarks' 'StOMP') ];
			package: 'FuelProgressUpdateBenchmarks' with: [ spec requires: #('FuelBenchmarks' 'FuelProgressUpdate') ];
                	package: 'FuelBenchmarksSRP' with: [ spec requires: #('FuelBenchmarks' 'SRP') ];
                	package: 'FuelBenchmarksEsAndEm' with: [ spec requires: #('FuelBenchmarks' 'EsAndEm') ];
			package: 'FuelPackageLoader' with: [ spec requires: #('Fuel' 'FuelMetalevel' ) ];	
			package: 'FuelPackageLoaderMetacello' with: [ spec requires: #( 'FuelPackageLoader' ) ];	
			package: 'FuelPackageLoaderTests' with: [ spec requires: #('FuelPackageLoader' 'FuelTests' )];
			package: 'FuelPreview' with: [ spec requires: #( 'FuelDebug' 'Roassal')];
			package: 'FuelMetalevel' with: [ spec requires: #( 'Fuel' )];
			package: 'FuelMetalevelTests' with: [ spec requires: #('FuelMetalevel' 'FuelTests' )].
		
                spec
				project: 'MagmaBase' with: [
				spec
					className: 'ConfigurationOfMaBase';
					loads: #('default');
					file: 'ConfigurationOfMaBase';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
				project: 'SIXX' with: [
				spec
					className: 'ConfigurationOfSIXX';
					loads: #('default');
					file: 'ConfigurationOfSIXX';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
				
		     spec
				project: 'StOMP' with: [
				spec
					className: 'ConfigurationOfStOMP';
					loads: #('default');
					file: 'ConfigurationOfStOMP';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
				project: 'Roassal' with: [
				spec
					className: 'ConfigurationOfRoassal';
					loads: #('default');
					file: 'ConfigurationOfRoassal';
					repository: 'http://www.squeaksource.com/Roassal' ].
				
		    spec
				project: 'FileSystem' with: [
				spec
					className: 'ConfigurationOfFilesystem';
					loads: #('default');
					file: 'ConfigurationOfFilesystem';
					repository: 'http://www.squeaksource.com/fs' ].

			spec
				package: 'SRP' with: [ spec repository: 'http://www.squeaksource.com/SRP' ].

			spec
				package: 'EsAndEm' with: [ spec repository: 'http://source.wiresong.ca/mc' ].

			spec
				group: 'CoreWithExtras' with: #('Core'  'FuelMetalevel' 'FuelProgressUpdate' 'FuelCompression');
				group: 'Tests' with: #('FuelTests' );
				group: 'PackageLoader' with: #('FuelPackageLoader' 'FuelPackageLoaderMetacello');
				group: 'PackageLoaderWithTests' with: #('PackageLoader' 'FuelPackageLoaderTests');
				group: 'BenchmarksSIXX' with: #('Benchmarks' 'FuelBenchmarksSIXX');
				group: 'BenchmarksAllBinarySerializers' with: #('Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelBenchmarksStomp' 'FuelBenchmarksMagma' 'FuelBenchmarksSRP' 'FuelBenchmarksEsAndEm');
				group: 'DevelopmentGroup' with: #('CoreWithExtras' 'Tests' 'FuelMetalevelTests' 'Benchmarks' 'FuelProgressUpdateBenchmarks' PackageLoader 'PackageLoaderWithTests' 'FuelDebug' 'FuelUtilities').
				
	].
		
	
	spec for: #'pharo2.0.x' do: [
		
		spec	
			package: 'FuelFileSystem';
			package: 'FuelFileSystemTests' with: [ spec requires: #('FuelTests')];
			package: 'FuelCommandLineHandler'.
								
		spec group: 'DevelopmentGroup' with: #('FuelFileSystem' 'FuelFileSystemTests' 'FuelCommandLineHandler').
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo21').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo21').
		
	].
	
	
	spec for: #'pharo1.4.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo20').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo20').
		
	].
	
	
	spec for: #'pharo1.3.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo14').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo20').
		
	].

			
			
	spec for: #'pharo1.2.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo13').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo20').
		
	].

	spec for: #'pharo1.1.x' do: [
	
		spec 
			package: 'Fuel' with: [ spec preLoadDoIt: #preLoadInPharo11].
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo12').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo20').
		
	].

	spec for: #'squeak4.1.x' do: [
			
		spec group: 'Core' with: #('FuelCompatibilityBeforeSqueak42').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak42').
			
	].

	spec for: #'squeak4.2.x' do: [
			
		spec group: 'Core' with: #('FuelCompatibilityBeforeSqueak44').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak44').
			
	].

	spec for: #'squeak4.3.x' do: [
			
		spec group: 'Core' with: #('FuelCompatibilityBeforeSqueak44').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak44').
			
	].

	spec for: #'squeak4.4.x' do: [
			
		spec group: 'Core' with: #('FuelCompatibilityBeforeSqueak45').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak45').
			
	].! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MartinDias 8/5/2013 14:07'!
baseline18: spec 
        <version: '1.8-baseline'>
        
	spec for: #squeakCommon do: [
		
		spec blessing: #baseline.
		self fuelRepository: spec.    

		spec 
			package: 'Fuel';
			package: 'FuelTests' with: [ spec requires: 'Fuel' ];
			package: 'FuelDebug' with: [ spec requires: 'Fuel' ];
			package: 'FuelUtilities';
			package: 'FuelProgressUpdate' with: [ spec requires: 'Fuel' ];
			package: 'FuelBenchmarks' with: [ spec requires: #('Fuel' 'FuelTests' 'FuelUtilities') ];
			package: 'FuelCompression'  with: [ spec requires: #('Fuel' 'FuelTests' ) ].
							
		spec
			package: 'FuelCompatibilityForSqueak' with: [ spec requires: #( 'FuelCompatibilityBeforePharo12' ) ];
			package: 'FuelCompatibilityBeforePharo12' with: [ spec requires: #( 'FuelCompatibilityBeforePharo13' ) ];
			package: 'FuelCompatibilityBeforePharo13' with: [ spec requires: #( 'FuelCompatibilityBeforePharo14' ) ];
			package: 'FuelCompatibilityBeforePharo14' with: [ spec requires: #( 'FuelCompatibilityBeforePharo20' ) ];
			package: 'FuelCompatibilityBeforePharo20' with: [ spec requires: #( 'Fuel' ) ].
			
		spec
			package: 'FuelTestsCompatibilityForSqueak' with: [ spec requires: #( 'FuelTests' ) ].
			
			
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Fuel');
			group: 'CoreWithExtras' with: #('Core' 'FuelProgressUpdate' 'FuelCompression');
			group: 'Tests' with: #('FuelTests');
			group: 'Benchmarks' with: #('FuelBenchmarks').
	].

	spec for: #pharo do: [
              
		spec
			package: 'FuelBenchmarksMagma' with: [ spec requires: #('FuelBenchmarks' 'MagmaBase') ];
                 	package: 'FuelBenchmarksSIXX' with: [ spec requires: #('FuelBenchmarks' 'SIXX') ];
                 	package: 'FuelBenchmarksStomp' with: [ spec requires: #('FuelBenchmarks' 'StOMP') ];
			package: 'FuelProgressUpdateBenchmarks' with: [ spec requires: #('FuelBenchmarks' 'FuelProgressUpdate') ];
                	package: 'FuelBenchmarksSRP' with: [ spec requires: #('FuelBenchmarks' 'SRP') ];
                	package: 'FuelBenchmarksEsAndEm' with: [ spec requires: #('FuelBenchmarks' 'EsAndEm') ];
			package: 'FuelPackageLoader' with: [ spec requires: #('Fuel' 'FuelMetalevel' ) ];	
			package: 'FuelPackageLoaderMetacello' with: [ spec requires: #( 'FuelPackageLoader' ) ];	
			package: 'FuelPackageLoaderTests' with: [ spec requires: #('FuelPackageLoader' 'FuelTests' )];
			package: 'FuelPreview' with: [ spec requires: #( 'FuelDebug' 'Roassal')];
			package: 'FuelMetalevel' with: [ spec requires: #( 'Fuel' )];
			package: 'FuelMetalevelTests' with: [ spec requires: #('FuelMetalevel' 'FuelTests' )].
		
                spec
				project: 'MagmaBase' with: [
				spec
					className: 'ConfigurationOfMaBase';
					loads: #('default');
					file: 'ConfigurationOfMaBase';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
				project: 'SIXX' with: [
				spec
					className: 'ConfigurationOfSIXX';
					loads: #('default');
					file: 'ConfigurationOfSIXX';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
				
		     spec
				project: 'StOMP' with: [
				spec
					className: 'ConfigurationOfStOMP';
					loads: #('default');
					file: 'ConfigurationOfStOMP';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
				project: 'Roassal' with: [
				spec
					className: 'ConfigurationOfRoassal';
					loads: #('default');
					file: 'ConfigurationOfRoassal';
					repository: 'http://www.squeaksource.com/Roassal' ].
				
		    spec
				project: 'FileSystem' with: [
				spec
					className: 'ConfigurationOfFilesystem';
					loads: #('default');
					file: 'ConfigurationOfFilesystem';
					repository: 'http://www.squeaksource.com/fs' ].

			spec
				package: 'SRP' with: [ spec repository: 'http://www.squeaksource.com/SRP' ].

			spec
				package: 'EsAndEm' with: [ spec repository: 'http://source.wiresong.ca/mc' ].

			spec
				group: 'CoreWithExtras' with: #('Core'  'FuelMetalevel' 'FuelProgressUpdate' 'FuelCompression');
				group: 'Tests' with: #('FuelTests' );
				group: 'PackageLoader' with: #('FuelPackageLoader' 'FuelPackageLoaderMetacello');
				group: 'PackageLoaderWithTests' with: #('PackageLoader' 'FuelPackageLoaderTests');
				group: 'BenchmarksSIXX' with: #('Benchmarks' 'FuelBenchmarksSIXX');
				group: 'BenchmarksAllBinarySerializers' with: #('Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelBenchmarksStomp' 'FuelBenchmarksMagma' 'FuelBenchmarksSRP' 'FuelBenchmarksEsAndEm');
				group: 'DevelopmentGroup' with: #('CoreWithExtras' 'Tests' 'FuelMetalevelTests' 'Benchmarks' 'FuelProgressUpdateBenchmarks' PackageLoader 'PackageLoaderWithTests' 'FuelDebug' 'FuelUtilities').
				
	].
		
	
	spec for: #'pharo2.0.x' do: [
		
		spec	
			package: 'FuelFileSystem';
			package: 'FuelFileSystemTests' with: [ spec requires: #('FuelTests')];
			package: 'FuelCommandLineHandler'.
								
		spec group: 'DevelopmentGroup' with: #('FuelFileSystem' 'FuelFileSystemTests' 'FuelCommandLineHandler').
		
	].
	
	
	spec for: #'pharo1.4.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo20').
		
	].
	
	
	spec for: #'pharo1.3.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo14').
		
	].

			
			
	spec for: #'pharo1.2.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo13').
		
	].

	spec for: #'pharo1.1.x' do: [
	
		spec 
			package: 'Fuel' with: [ spec preLoadDoIt: #preLoadInPharo11].
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo12').
		
	].


	spec for: #squeak do: [
			
		spec group: 'Core' with: #('FuelCompatibilityForSqueak').
		spec group: 'Tests' with: #('FuelTestsCompatibilityForSqueak').
			
	].
! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MaxLeske 11/25/2013 07:39'!
baseline192: spec 
        <version: '1.9.2-baseline'>
        
	spec for: #common do: [
		
		spec blessing: #baseline.
		self fuelRepository: spec.    

		spec 
			package: 'Fuel';
			package: 'FuelTests' with: [ spec requires: 'Fuel' ];
			package: 'FuelDebug' with: [ spec requires: 'Fuel' ];
			package: 'FuelUtilities';
			package: 'FuelProgressUpdate' with: [ spec requires: #('Fuel' 'Tests') ];
			package: 'FuelBenchmarks' with: [ spec requires: #('Fuel' 'Tests' 'FuelUtilities' 'FuelMetalevel') ].
							
		spec
			package: 'FuelCompatibilityBeforePharo12' with: [ spec requires: #( 'FuelCompatibilityBeforePharo13' ) ];
			package: 'FuelCompatibilityBeforePharo13' with: [ spec requires: #( 'FuelCompatibilityBeforePharo14' ) ];
			package: 'FuelCompatibilityBeforePharo14' with: [ spec requires: #( 'FuelCompatibilityBeforePharo20' ) ];
			package: 'FuelCompatibilityBeforePharo20' with: [ spec requires: #( 'FuelCompatibilityBeforePharo30' ) ];
			package: 'FuelCompatibilityBeforePharo30' with: [ spec requires: #( 'Fuel' ) ].
			
		spec
			package: 'FuelCompatibilityBeforeSqueak42' with: [ spec requires: #( 'FuelCompatibilityBeforeSqueak44' ) ];	
			package: 'FuelCompatibilityBeforeSqueak44' with: [ spec requires: #( 'FuelCompatibilityBeforeSqueak45' ) ];	
			package: 'FuelCompatibilityBeforeSqueak45' with: [ spec requires: #( 'Fuel' ) ].

		spec
			package: 'FuelTestsCompatibilityBeforePharo12' with: [ spec requires: #( 'FuelTestsCompatibilityBeforePharo20' ) ];
			package: 'FuelTestsCompatibilityBeforePharo20' with: [ spec requires: #( 'FuelTestsCompatibilityBeforePharo30' ) ];
			package: 'FuelTestsCompatibilityBeforePharo30' with: [ spec requires: #( 'FuelTests' ) ].

		spec
			package: 'FuelTestsCompatibilityBeforeSqueak42' with: [ spec requires: #( 'FuelTestsCompatibilityBeforeSqueak43' ) ];
			package: 'FuelTestsCompatibilityBeforeSqueak43' with: [ spec requires: #( 'FuelTestsCompatibilityBeforeSqueak44' ) ];
			package: 'FuelTestsCompatibilityBeforeSqueak44' with: [ spec requires: #( 'FuelTestsCompatibilityBeforeSqueak45' ) ];
			package: 'FuelTestsCompatibilityBeforeSqueak45' with: [ spec requires: #( 'FuelTests' ) ].
			
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Fuel');
			group: 'CoreWithExtras' with: #('Core' 'FuelProgressUpdate');
			group: 'Tests' with: #('Core' 'FuelTests');
			group: 'Benchmarks' with: #('Core' 'FuelBenchmarks').
	].

	spec for: #pharo do: [
              
		spec
			package: 'FuelBenchmarksMagma' with: [ spec requires: #('FuelBenchmarks' 'MagmaBase') ];
			package: 'FuelBenchmarksSIXX' with: [ spec requires: #('FuelBenchmarks' 'SIXX') ];
			package: 'FuelBenchmarksStomp' with: [ spec requires: #('FuelBenchmarks' 'StOMP') ];
			package: 'FuelProgressUpdateBenchmarks' with: [ spec requires: #('FuelBenchmarks' 'FuelProgressUpdate') ];
			package: 'FuelBenchmarksSRP' with: [ spec requires: #('FuelBenchmarks' 'SRP') ];
			package: 'FuelBenchmarksEsAndEm' with: [ spec requires: #('FuelBenchmarks' 'EsAndEm') ];
			package: 'FuelPreview' with: [ spec requires: #( 'FuelDebug' 'Roassal')];
			package: 'FuelMetalevel' with: [ spec requires: #( 'Fuel' )];
			package: 'FuelMetalevelTests' with: [ spec requires: #('FuelMetalevel' 'FuelTests' )].
		
		self 
			magma: spec;
			sixx: spec;
			stomp: spec;
			srp: spec;
			esAndEm: spec;
			roassal: spec.

		spec
			group: 'CoreWithExtras' with: #('Core'  'FuelMetalevel' 'FuelProgressUpdate');
			group: 'Tests' with: #('FuelTests' );
			group: 'BenchmarksSIXX' with: #('Benchmarks' 'FuelBenchmarksSIXX');
			group: 'BenchmarksAllBinarySerializers' with: #('Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelBenchmarksStomp' 'FuelBenchmarksMagma' 'FuelBenchmarksSRP' 'FuelBenchmarksEsAndEm');
			group: 'DevelopmentGroup' with: #('CoreWithExtras' 'Tests' 'FuelMetalevelTests' 'Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelDebug' 'FuelUtilities'). 
	].
		
	
	spec for: #'pharo2.0.x' do: [
		
		spec	
			package: 'FuelTools-Debugger' with: [ spec requires: #('Fuel' ) ];
			package: 'FuelCommandLineHandler' with: [ spec requires: #('Fuel' ) ];
			package: 'FuelSystem-FileRegistry' with: [ spec requires: #('Fuel' ) ].
												
		spec 
			group: 'kernel' with: #( 'FuelCommandLineHandler' );
			group: 'Core' with: #('FuelCompatibilityBeforePharo30' 'FuelCommandLineHandler' 'FuelSystem-FileRegistry' 'FuelTools-Debugger');
			group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo30').
	].
	
	
	spec for: #'pharo1.4.x' do: [
		
		spec 
			group: 'Core' with: #('FuelCompatibilityBeforePharo20');
			group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo20').
		
	].
	
	
	spec for: #'pharo1.3.x' do: [
		
		spec 
			group: 'Core' with: #('FuelCompatibilityBeforePharo14');
			group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo20').
		
	].
	
	
	spec for: #'pharo1.2.x' do: [
		
		spec 
			group: 'Core' with: #('FuelCompatibilityBeforePharo13');
			group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo20').
		
	].


	spec for: #'pharo1.1.x' do: [
	
		spec 
			package: 'Fuel' with: [ spec preLoadDoIt: #preLoadInPharo11].
		
		spec 
			group: 'Core' with: #('FuelCompatibilityBeforePharo12');
			group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo12').
		
	].


	spec for: #'squeak4.1.x' do: [
			
		spec 
			group: 'Core' with: #('FuelCompatibilityBeforeSqueak42');
			group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak42').
			
	].


	spec for: #'squeak4.2.x' do: [
			
		spec 
			group: 'Core' with: #('FuelCompatibilityBeforeSqueak44');
			group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak43').
			
	].


	spec for: #'squeak4.3.x' do: [
			
		spec 
			group: 'Core' with: #('FuelCompatibilityBeforeSqueak44');
			group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak44').
			
	].


	spec for: #'squeak4.4.x' do: [
			
		spec 
			group: 'Core' with: #('FuelCompatibilityBeforeSqueak45');
			group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak45').
			
	].! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MaxLeske 2/23/2016 20:56'!
baseline193: spec 
        <version: '1.9.3-baseline'>
        
	spec for: #common do: [
		
		spec
			blessing: #baseline;
			postLoadDoIt: #addPostloadHacks.
		self fuelRepository: spec.    

		spec 
			package: 'Fuel';
			package: 'FuelTests' with: [ spec requires: 'Fuel' ];
			package: 'FuelDebug' with: [ spec requires: 'Fuel' ];
			package: 'FuelUtilities';
			package: 'FuelProgressUpdate' with: [ spec requires: #('Fuel' 'Tests') ];
			package: 'FuelBenchmarks' with: [ spec requires: #('Fuel' 'Tests' 'FuelUtilities' 'FuelMetalevel') ].
			
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Fuel');
			group: 'CoreWithExtras' with: #('Core' 'FuelProgressUpdate');
			group: 'Tests' with: #('Core' 'FuelTests');
			group: 'Benchmarks' with: #('Core' 'FuelBenchmarks').
	].

	spec for: #pharo do: [
              
		spec
			package: 'FuelBenchmarksMagma' with: [ spec requires: #('FuelBenchmarks' 'MagmaBase') ];
			package: 'FuelBenchmarksSIXX' with: [ spec requires: #('FuelBenchmarks' 'SIXX') ];
			package: 'FuelBenchmarksStomp' with: [ spec requires: #('FuelBenchmarks' 'StOMP') ];
			package: 'FuelProgressUpdateBenchmarks' with: [ spec requires: #('FuelBenchmarks' 'FuelProgressUpdate') ];
			package: 'FuelBenchmarksSRP' with: [ spec requires: #('FuelBenchmarks' 'SRP') ];
			package: 'FuelBenchmarksEsAndEm' with: [ spec requires: #('FuelBenchmarks' 'EsAndEm') ];
			package: 'FuelPreview' with: [ spec requires: #( 'FuelDebug' 'Roassal')];
			package: 'FuelMetalevel' with: [ spec requires: #( 'Fuel' )];
			package: 'FuelMetalevelTests' with: [ spec requires: #('FuelMetalevel' 'FuelTests' )].
		
		self 
			magma: spec;
			sixx: spec;
			stomp: spec;
			srp: spec;
			esAndEm: spec;
			roassal: spec.

		spec
			group: 'CoreWithExtras' with: #('Core'  'FuelMetalevel' 'FuelProgressUpdate');
			group: 'Tests' with: #('FuelTests' );
			group: 'BenchmarksSIXX' with: #('Benchmarks' 'FuelBenchmarksSIXX');
			group: 'BenchmarksAllBinarySerializers' with: #('Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelBenchmarksStomp' 'FuelBenchmarksMagma' 'FuelBenchmarksSRP' 'FuelBenchmarksEsAndEm');
			group: 'DevelopmentGroup' with: #('CoreWithExtras' 'Tests' 'FuelMetalevelTests' 'Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelDebug' 'FuelUtilities'). 
	].
		
	
	spec for: #'pharo2.0.x' do: [
		
		spec	
			package: 'FuelTools-Debugger' with: [ spec requires: #('Fuel' ) ];
			package: 'FuelCommandLineHandler' with: [ spec requires: #('Fuel' ) ];
			package: 'FuelSystem-FileRegistry' with: [ spec requires: #('Fuel' ) ].
												
		spec 
			group: 'kernel' with: #( 'FuelCommandLineHandler' );
			group: 'Core' with: #('FuelCommandLineHandler' 'FuelSystem-FileRegistry' 'FuelTools-Debugger');
			group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo30').
	]! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'TravisCI 2/20/2016 17:43'!
baseline194: spec 
        <version: '1.9.4-baseline'>
        
	spec for: #common do: [
		
		spec
			blessing: #baseline;
			postLoadDoIt: #addPostloadHacks.

		self fuelRepository: spec.    

		spec 
			package: 'Fuel';
			package: 'FuelTests' with: [ spec requires: 'Fuel' ];
			package: 'FuelDebug' with: [ spec requires: 'Fuel' ];
			package: 'FuelUtilities';
			package: 'FuelProgressUpdate' with: [ spec requires: #('Fuel' 'Tests') ];
			package: 'FuelBenchmarks' with: [ spec requires: #('Fuel' 'Tests' 'FuelUtilities' 'FuelMetalevel') ].
			
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Fuel');
			group: 'Tests' with: #('Core' 'FuelTests')
		].

	spec for: #pharo do: [
              
		spec
			package: 'FuelBenchmarksMagma' with: [ spec requires: #('FuelBenchmarks' 'MagmaBase') ];
			package: 'FuelBenchmarksSIXX' with: [ spec requires: #('FuelBenchmarks' 'SIXX') ];
			package: 'FuelBenchmarksStomp' with: [ spec requires: #('FuelBenchmarks' 'StOMP') ];
			package: 'FuelProgressUpdateBenchmarks' with: [ spec requires: #('FuelBenchmarks' 'FuelProgressUpdate') ];
			package: 'FuelBenchmarksSRP' with: [ spec requires: #('FuelBenchmarks' 'SRP') ];
			package: 'FuelBenchmarksEsAndEm' with: [ spec requires: #('FuelBenchmarks' 'EsAndEm') ];
			package: 'FuelPreview' with: [ spec requires: #( 'FuelDebug' 'Roassal')];
			package: 'FuelMetalevel' with: [ spec requires: #( 'Fuel' )];
			package: 'FuelMetalevelTests' with: [ spec requires: #('FuelMetalevel' 'FuelTests' )].
		
		self 
			magma: spec;
			sixx: spec;
			stomp: spec;
			srp: spec;
			esAndEm: spec;
			roassal: spec.

		spec
			group: 'CoreWithExtras' with: #('Core' 'FuelMetalevel' 'FuelProgressUpdate');
			group: 'Tests' with: #('FuelTests' );
			group: 'Benchmarks' with: #('Core' 'FuelBenchmarks');
			group: 'BenchmarksSIXX' with: #('Benchmarks' 'FuelBenchmarksSIXX');
			group: 'BenchmarksAllBinarySerializers' with: #('Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelBenchmarksStomp' 'FuelBenchmarksMagma' 'FuelBenchmarksSRP' 'FuelBenchmarksEsAndEm');
			group: 'DevelopmentGroup' with: #('CoreWithExtras' 'Tests' 'FuelMetalevelTests' 'Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelDebug' 'FuelUtilities'). 
	].
		
	spec for: #'pharo2.0.x' do: [
		
		spec	
			package: 'FuelTools-Debugger' with: [ spec requires: #('Fuel' ) ];
			package: 'FuelCommandLineHandler' with: [ spec requires: #('Fuel' ) ];
			package: 'FuelSystem-FileRegistry' with: [ spec requires: #('Fuel' ) ].
												
		spec 
			group: 'kernel' with: #( 'FuelCommandLineHandler' );
			group: 'Core' with: #('FuelCommandLineHandler' 'FuelSystem-FileRegistry' 'FuelTools-Debugger').
	].! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MaxLeske 11/25/2013 07:02'!
baseline19: spec 
        <version: '1.9-baseline'>
        
	spec for: #common do: [
		
		spec blessing: #baseline.
		self fuelRepository: spec.    

		spec 
			package: 'Fuel';
			package: 'FuelTests' with: [ spec requires: 'Fuel' ];
			package: 'FuelDebug' with: [ spec requires: 'Fuel' ];
			package: 'FuelUtilities';
			package: 'FuelProgressUpdate' with: [ spec requires: 'Fuel' ];
			package: 'FuelBenchmarks' with: [ spec requires: #('Fuel' 'FuelTests' 'FuelUtilities' 'FuelMetalevel') ].
							
		spec
			package: 'FuelCompatibilityBeforePharo12' with: [ spec requires: #( 'FuelCompatibilityBeforePharo13' ) ];
			package: 'FuelCompatibilityBeforePharo13' with: [ spec requires: #( 'FuelCompatibilityBeforePharo14' ) ];
			package: 'FuelCompatibilityBeforePharo14' with: [ spec requires: #( 'FuelCompatibilityBeforePharo20' ) ];
			package: 'FuelCompatibilityBeforePharo20' with: [ spec requires: #( 'Fuel' ) ].
			
		spec
			package: 'FuelCompatibilityBeforeSqueak42' with: [ spec requires: #( 'FuelCompatibilityBeforeSqueak44' ) ];	
			package: 'FuelCompatibilityBeforeSqueak44' with: [ spec requires: #( 'FuelCompatibilityBeforeSqueak45' ) ];	
			package: 'FuelCompatibilityBeforeSqueak45' with: [ spec requires: #( 'Fuel' ) ].

		spec
			package: 'FuelTestsCompatibilityBeforePharo12' with: [ spec requires: #( 'FuelTestsCompatibilityBeforePharo20' ) ];
			package: 'FuelTestsCompatibilityBeforePharo20' with: [ spec requires: #( 'FuelTestsCompatibilityBeforePharo30' ) ];
			package: 'FuelTestsCompatibilityBeforePharo30' with: [ spec requires: #( 'FuelTests' ) ].

		spec
			package: 'FuelTestsCompatibilityBeforeSqueak42' with: [ spec requires: #( 'FuelTestsCompatibilityBeforeSqueak43' ) ];
			package: 'FuelTestsCompatibilityBeforeSqueak43' with: [ spec requires: #( 'FuelTestsCompatibilityBeforeSqueak44' ) ];
			package: 'FuelTestsCompatibilityBeforeSqueak44' with: [ spec requires: #( 'FuelTestsCompatibilityBeforeSqueak45' ) ];
			package: 'FuelTestsCompatibilityBeforeSqueak45' with: [ spec requires: #( 'FuelTests' ) ].
			
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Fuel');
			group: 'CoreWithExtras' with: #('Core' 'FuelProgressUpdate');
			group: 'Tests' with: #('FuelTests');
			group: 'Benchmarks' with: #('FuelBenchmarks').
	].

	spec for: #pharo do: [
              
		spec
			package: 'FuelBenchmarksMagma' with: [ spec requires: #('FuelBenchmarks' 'MagmaBase') ];
                 	package: 'FuelBenchmarksSIXX' with: [ spec requires: #('FuelBenchmarks' 'SIXX') ];
                 	package: 'FuelBenchmarksStomp' with: [ spec requires: #('FuelBenchmarks' 'StOMP') ];
			package: 'FuelProgressUpdateBenchmarks' with: [ spec requires: #('FuelBenchmarks' 'FuelProgressUpdate') ];
                	package: 'FuelBenchmarksSRP' with: [ spec requires: #('FuelBenchmarks' 'SRP') ];
                	package: 'FuelBenchmarksEsAndEm' with: [ spec requires: #('FuelBenchmarks' 'EsAndEm') ];
			package: 'FuelPreview' with: [ spec requires: #( 'FuelDebug' 'Roassal')];
			package: 'FuelMetalevel' with: [ spec requires: #( 'Fuel' )];
			package: 'FuelMetalevelTests' with: [ spec requires: #('FuelMetalevel' 'FuelTests' )].
		
                spec
				project: 'MagmaBase' with: [
				spec
					className: 'ConfigurationOfMaBase';
					loads: #('default');
					file: 'ConfigurationOfMaBase';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
				project: 'SIXX' with: [
				spec
					className: 'ConfigurationOfSIXX';
					loads: #('default');
					file: 'ConfigurationOfSIXX';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
				
		     spec
				project: 'StOMP' with: [
				spec
					className: 'ConfigurationOfStOMP';
					loads: #('default');
					file: 'ConfigurationOfStOMP';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
				project: 'Roassal' with: [
				spec
					className: 'ConfigurationOfRoassal';
					loads: #('default');
					file: 'ConfigurationOfRoassal';
					repository: 'http://www.squeaksource.com/Roassal' ].

			spec
				package: 'SRP' with: [ spec repository: 'http://www.squeaksource.com/SRP' ].

			spec
				package: 'EsAndEm' with: [ spec repository: 'http://source.wiresong.ca/mc' ].

			spec
				group: 'CoreWithExtras' with: #('Core'  'FuelMetalevel' 'FuelProgressUpdate');
				group: 'Tests' with: #('FuelTests' );
				group: 'BenchmarksSIXX' with: #('Benchmarks' 'FuelBenchmarksSIXX');
				group: 'BenchmarksAllBinarySerializers' with: #('Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelBenchmarksStomp' 'FuelBenchmarksMagma' 'FuelBenchmarksSRP' 'FuelBenchmarksEsAndEm');
				group: 'DevelopmentGroup' with: #('CoreWithExtras' 'Tests' 'FuelMetalevelTests' 'Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelDebug' 'FuelUtilities').
			
	].
		
	
	spec for: #'pharo2.0.x' do: [
		
		spec	
			package: 'FuelTools-Debugger' with: [ spec requires: #('Fuel' ) ];
			package: 'FuelCommandLineHandler' with: [ spec requires: #('Fuel' ) ];
			package: 'FuelSystem-FileRegistry' with: [ spec requires: #('Fuel' ) ].
												
		spec group: 'kernel' with: #( 'FuelCommandLineHandler' ).
		spec group: 'Core' with: #('FuelCommandLineHandler' 'FuelSystem-FileRegistry' 'FuelTools-Debugger').	
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo30').
	].
	
	
	spec for: #'pharo1.4.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo20').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo20').
		
	].
	
	
	spec for: #'pharo1.3.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo14').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo20').
		
	].
	
	
	spec for: #'pharo1.2.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo13').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforePharo20').
		
	].


	spec for: #'pharo1.1.x' do: [
	
		spec 
			package: 'Fuel' with: [ spec preLoadDoIt: #preLoadInPharo11].
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo12').
		
	].


	spec for: #'squeak4.1.x' do: [
			
		spec group: 'Core' with: #('FuelCompatibilityBeforeSqueak42').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak42').
			
	].


	spec for: #'squeak4.2.x' do: [
			
		spec group: 'Core' with: #('FuelCompatibilityBeforeSqueak44').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak43').
			
	].


	spec for: #'squeak4.3.x' do: [
			
		spec group: 'Core' with: #('FuelCompatibilityBeforeSqueak44').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak44').
			
	].


	spec for: #'squeak4.4.x' do: [
			
		spec group: 'Core' with: #('FuelCompatibilityBeforeSqueak45').
		spec group: 'Tests' with: #('FuelTestsCompatibilityBeforeSqueak45').
			
	].! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MartinDias 8/5/2013 14:09'!
baseline19AlphaForTanker: spec 
	<version: '1.9-alphaForTanker-baseline'>

	spec for: #squeakCommon do: [
		
		spec blessing: #baseline.
		self fuelRepository: spec.    

		spec 
			package: 'Fuel';
			package: 'FuelTests' with: [ spec requires: 'Fuel' ];
			package: 'FuelDebug' with: [ spec requires: 'Fuel' ];
			package: 'FuelUtilities';
			package: 'FuelProgressUpdate' with: [ spec requires: 'Fuel' ];
			package: 'FuelBenchmarks' with: [ spec requires: #('Fuel' 'FuelTests' 'FuelUtilities') ];
			package: 'FuelCompression'  with: [ spec requires: #('Fuel' 'FuelTests' ) ].
							
		spec
			package: 'FuelCompatibilityForSqueak' with: [ spec requires: #( 'FuelCompatibilityBeforePharo12' ) ];
			package: 'FuelCompatibilityBeforePharo12' with: [ spec requires: #( 'FuelCompatibilityBeforePharo13' ) ];
			package: 'FuelCompatibilityBeforePharo13' with: [ spec requires: #( 'FuelCompatibilityBeforePharo14' ) ];
			package: 'FuelCompatibilityBeforePharo14' with: [ spec requires: #( 'FuelCompatibilityBeforePharo20' ) ];
			package: 'FuelCompatibilityBeforePharo20' with: [ spec requires: #( 'Fuel' ) ].
			
		spec
			package: 'FuelTestsCompatibilityForSqueak' with: [ spec requires: #( 'FuelTests' ) ].
			
			
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Fuel');
			group: 'CoreWithExtras' with: #('Core' 'FuelProgressUpdate' 'FuelCompression');
			group: 'Tests' with: #('FuelTests');
			group: 'Benchmarks' with: #('FuelBenchmarks').
	].

	spec for: #pharo do: [
              
		spec
			package: 'FuelBenchmarksMagma' with: [ spec requires: #('FuelBenchmarks' 'MagmaBase') ];
                 	package: 'FuelBenchmarksSIXX' with: [ spec requires: #('FuelBenchmarks' 'SIXX') ];
                 	package: 'FuelBenchmarksStomp' with: [ spec requires: #('FuelBenchmarks' 'StOMP') ];
			package: 'FuelProgressUpdateBenchmarks' with: [ spec requires: #('FuelBenchmarks' 'FuelProgressUpdate') ];
                	package: 'FuelBenchmarksSRP' with: [ spec requires: #('FuelBenchmarks' 'SRP') ];
                	package: 'FuelBenchmarksEsAndEm' with: [ spec requires: #('FuelBenchmarks' 'EsAndEm') ];
			package: 'FuelPreview' with: [ spec requires: #( 'FuelDebug' 'Roassal')];
			package: 'FuelMetalevel' with: [ spec requires: #( 'Fuel' )];
			package: 'FuelMetalevelTests' with: [ spec requires: #('FuelMetalevel' 'FuelTests' )].
		
                spec
				project: 'MagmaBase' with: [
				spec
					className: 'ConfigurationOfMaBase';
					loads: #('default');
					file: 'ConfigurationOfMaBase';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
				project: 'SIXX' with: [
				spec
					className: 'ConfigurationOfSIXX';
					loads: #('default');
					file: 'ConfigurationOfSIXX';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
				
		     spec
				project: 'StOMP' with: [
				spec
					className: 'ConfigurationOfStOMP';
					loads: #('default');
					file: 'ConfigurationOfStOMP';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

                spec
				project: 'Roassal' with: [
				spec
					className: 'ConfigurationOfRoassal';
					loads: #('default');
					file: 'ConfigurationOfRoassal';
					repository: 'http://www.squeaksource.com/Roassal' ].

			spec
				package: 'SRP' with: [ spec repository: 'http://www.squeaksource.com/SRP' ].

			spec
				package: 'EsAndEm' with: [ spec repository: 'http://source.wiresong.ca/mc' ].

			spec
				group: 'CoreWithExtras' with: #('Core'  'FuelMetalevel' 'FuelProgressUpdate' 'FuelCompression');
				group: 'Tests' with: #('FuelTests' );
				group: 'BenchmarksSIXX' with: #('Benchmarks' 'FuelBenchmarksSIXX');
				group: 'BenchmarksAllBinarySerializers' with: #('Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelBenchmarksStomp' 'FuelBenchmarksMagma' 'FuelBenchmarksSRP' 'FuelBenchmarksEsAndEm');
				group: 'DevelopmentGroup' with: #('CoreWithExtras' 'Tests' 'FuelMetalevelTests' 'Benchmarks' 'FuelProgressUpdateBenchmarks' 'FuelDebug' 'FuelUtilities').
				
	].
		
	
	spec for: #'pharo2.0.x' do: [
		
		spec	
			package: 'FuelCommandLineHandler'.
								
		spec group: 'DevelopmentGroup' with: #('FuelCommandLineHandler').
		
	].
	
	
	spec for: #'pharo1.4.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo20').
		
	].
	
	
	spec for: #'pharo1.3.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo14').
		
	].

			
			
	spec for: #'pharo1.2.x' do: [
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo13').
		
	].

	spec for: #'pharo1.1.x' do: [
	
		spec 
			package: 'Fuel' with: [ spec preLoadDoIt: #preLoadInPharo11].
		
		spec group: 'Core' with: #('FuelCompatibilityBeforePharo12').
		
	].


	spec for: #squeak do: [
			
		spec group: 'Core' with: #('FuelCompatibilityForSqueak').
		spec group: 'Tests' with: #('FuelTestsCompatibilityForSqueak').
			
	].
! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'MaxLeske 2/22/2016 23:06'!
baseline200: spec 
	<version: '2.0.0-baseline'>
        
	spec for: #common do: [
		
		spec
			blessing: #baseline;
			postLoadDoIt: #addPostloadHacks.

		self fuelRepository: spec.    
		
		self smark: spec.

		spec 
			package: 'Fuel';
			package: 'FuelTests' with: [ spec requires: 'Fuel' ];
			package: 'FuelDebug' with: [ spec requires: 'Fuel' ];
			package: 'FuelProgressUpdate' with: [ spec requires: #('Fuel' 'Tests') ];
			package: 'FuelBenchmarks' with: [ spec requires: #('Fuel' 'Tests' 'SMark-Jenkins') ].
					
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Fuel');
			group: 'CoreWithExtras' with: #('Core' 'FuelProgressUpdate');
			group: 'Tests' with: #('Core' 'FuelTests');
			group: 'Benchmarks' with: #('Core' 'FuelBenchmarks').
	].

	self groupsForBaseline200PharoCommon: spec! !

!ConfigurationOfFuel methodsFor: 'baselines' stamp: 'EstebanLorenzano 2/26/2016 12:32'!
baseline210: spec 
	<version: '2.1.0-baseline'>
        
	spec for: #common do: [
		
		spec
			blessing: #baseline;
			postLoadDoIt: #addPostloadHacks.

		self fuelRepository: spec.    
		
		self smark: spec.

		spec
			package: 'Fuel';
			package: 'FuelTests' with: [ spec requires: 'Fuel' ];
			package: 'FuelDebug' with: [ spec requires: 'Fuel' ];
			package: 'FuelProgressUpdate' with: [ spec requires: #('Fuel' 'Tests') ];
			package: 'FuelBenchmarks' with: [ spec requires: #('Fuel' 'Tests' 'SMark-Jenkins') ].
					
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Fuel');
			group: 'CoreWithExtras' with: #('Core' 'FuelProgressUpdate');
			group: 'Tests' with: #('Core' 'FuelTests');
			group: 'Benchmarks' with: #('Core' 'FuelBenchmarks').
	].

	self groupsForBaseline200PharoCommon: spec! !

!ConfigurationOfFuel methodsFor: 'symbolic versions' stamp: 'MaxLeske 3/4/2016 13:26'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #common version: '2.1.0-baseline'! !

!ConfigurationOfFuel methodsFor: 'baselines-helpers' stamp: 'MartinDias 8/5/2013 14:34'!
esAndEm: spec
	spec
		package: 'EsAndEm' with: [ spec repository: 'http://source.wiresong.ca/mc' ]! !

!ConfigurationOfFuel methodsFor: 'baselines-helpers' stamp: 'MartinDias 8/5/2013 14:01'!
fuelRepository: spec 
	spec repository: 'http://smalltalkhub.com/mc/Pharo/Fuel/main'! !

!ConfigurationOfFuel methodsFor: 'baselines-helpers' stamp: 'MaxLeske 2/22/2016 23:17'!
groupsForBaseline200PharoCommon: spec
	spec for: #pharo do: [              
		spec
			package: 'FuelPreview' with: [ spec requires: #( 'FuelDebug' 'Roassal')];
			package: 'FuelMetalevel' with: [ spec requires: #( 'Fuel' )];
			package: 'FuelMetalevelTests' with: [ spec requires: #('FuelMetalevel' 'FuelTests' )].
		
		self roassal: spec.

		spec
			group: 'CoreWithExtras' with: #('Core'  'FuelMetalevel' 'FuelProgressUpdate');
			group: 'Tests' with: #('FuelTests' );
			group: 'DevelopmentGroup' with: #('CoreWithExtras' 'Tests' 'FuelMetalevelTests' 'FuelDebug'). 
	]! !

!ConfigurationOfFuel methodsFor: 'baselines-helpers' stamp: 'MartinDias 8/5/2013 14:29'!
magma: spec
	spec
		project: 'MagmaBase' with: [
			spec
				className: 'ConfigurationOfMaBase';
				loads: #('default');
				file: 'ConfigurationOfMaBase';
				repository: 'http://www.squeaksource.com/MetacelloRepository' ].
! !

!ConfigurationOfFuel methodsFor: 'accessing' stamp: 'MaxLeske 2/19/2016 11:29'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class
			ensureMetacello;
			addHacks.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		
		project ]! !

!ConfigurationOfFuel methodsFor: 'baselines-helpers' stamp: 'MartinDias 8/5/2013 14:31'!
roassal: spec		
	spec
		project: 'Roassal' with: [
			spec
				className: 'ConfigurationOfRoassal';
				loads: #('default');
				file: 'ConfigurationOfRoassal';
				repository: 'http://www.squeaksource.com/Roassal' ]! !

!ConfigurationOfFuel methodsFor: 'baselines-helpers' stamp: 'MartinDias 8/5/2013 14:29'!
sixx: spec		
	spec
		project: 'SIXX' with: [
			spec
				className: 'ConfigurationOfSIXX';
				loads: #('default');
				file: 'ConfigurationOfSIXX';
				repository: 'http://www.squeaksource.com/MetacelloRepository' ]! !

!ConfigurationOfFuel methodsFor: 'baselines-helpers' stamp: 'MartinDias 7/18/2014 15:54'!
smark: spec		
	spec
		project: 'SMark' with: [
			spec
				className: 'ConfigurationOfSMark';
                        versionString: #development;
				file: 'ConfigurationOfSMark';
				repository: 'http://smalltalkhub.com/mc/StefanMarr/SMark/main' ].

	spec
		package: 'SMark-Jenkins' with: [ 
			spec 
				repository: 'http://smalltalkhub.com/mc/ClementBera/classic-bench/main';
				requires: 'SMark' ].
! !

!ConfigurationOfFuel methodsFor: 'baselines-helpers' stamp: 'MartinDias 8/5/2013 14:34'!
srp: spec		
	spec
		package: 'SRP' with: [ spec repository: 'http://www.squeaksource.com/SRP' ]! !

!ConfigurationOfFuel methodsFor: 'symbolic versions' stamp: 'EstebanLorenzano 2/26/2016 12:33'!
stable: spec
	<symbolicVersion: #'stable'>
	spec
		for: #common version: '2.1.0';
		for: #'pharo1.x' version: '1.9.4';
		for: #'pharo2.x' version: '1.9.4';
		for: #'pharo3.x' version: '1.9.4';
		for: #'pharo4.x' version: '1.9.4';
		for: #'squeak4.x' version: '1.9.4'! !

!ConfigurationOfFuel methodsFor: 'baselines-helpers' stamp: 'MartinDias 8/5/2013 14:30'!
stomp: spec
	spec
		project: 'StOMP' with: [
			spec
				className: 'ConfigurationOfStOMP';
				loads: #('default');
				file: 'ConfigurationOfStOMP';
				repository: 'http://www.squeaksource.com/MetacelloRepository' ]! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MartinDias 5/24/2011 15:26'!
version10: spec 
        <version: '1.0' imports: #('1.0-baseline') >
        
        spec for: #pharo do: [
                spec blessing: #release.
                spec 
                        package: 'Fuel' with: 'Fuel-MartinDias.84';
                        package: 'FuelBenchmarks' with: 'FuelBenchmarks-MartinDias.4';
				package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.1';
				package: 'FuelBenchmarksMC2' with: 'FuelBenchmarksMC2-MartinDias.1' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MartinDias 5/24/2011 15:26'!
version11: spec 
        <version: '1.1' imports: #('1.1-baseline') >
        
        spec for: #pharo do: [
                spec blessing: #release.
                spec 
                        package: 'Fuel' with: 'Fuel-MartinDias.84';
                        package: 'FuelBenchmarks' with: 'FuelBenchmarks-MartinDias.4';
				package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.4';
				package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.1';
				package: 'FuelBenchmarksMC2' with: 'FuelBenchmarksMC2-MartinDias.1' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MartinDias 5/24/2011 15:25'!
version12: spec 
        <version: '1.2' imports: #('1.2-baseline') >
        
        spec for: #pharo do: [
                spec blessing: #release.
                spec 
                        package: 'Fuel' with: 'Fuel-MartinDias.193';
				package: 'FuelTests' with: 'FuelTests-MartinDias.2';
                        package: 'FuelBenchmarks' with: 'FuelBenchmarks-MarianoMartinezPeck.9';
				package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.6';
				package: 'FuelContainer' with: 'FuelContainer-MartinDias.1';
				package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.3';
				package: 'FuelBenchmarksMC2' with: 'FuelBenchmarksMC2-MartinDias.1' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MarianoMartinezPeck 6/1/2011 14:04'!
version13: spec 
        <version: '1.3' imports: #('1.2-baseline') >
        
        spec for: #pharo do: [
                spec blessing: #release.
		    spec description: '
					- Class serialization without ClassBuilder.
					- MethodContext and BlockClosure serialization.
					- Some fixes on configuration itself
				'.
                spec 
                        package: 'Fuel' with: 'Fuel-MarianoMartinezPeck.225';
				package: 'FuelTests' with: 'FuelTests-MarianoMartinezPeck.21';
                        package: 'FuelBenchmarks' with: 'FuelBenchmarks-MarianoMartinezPeck.20';
				package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.6';
				package: 'FuelContainer' with: 'FuelContainer-MartinDias.1';
				package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.3';
				package: 'FuelBenchmarksMC2' with: 'FuelBenchmarksMC2-MartinDias.1' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MarianoMartinezPeck 6/1/2011 14:03'!
version14: spec 
        <version: '1.4' imports: #('1.2-baseline') >
        
        spec for: #pharo do: [
                spec blessing: #release.
		    spec description: '
				- New support for serialization in memory
				- Name refactorings in some hierarchies and protocols.
				- Object cluster big refactoring
				- Hack that avoids several OrderedCollection>>makeRoomAtLast.
				- Other cleanups
			'.
                spec 
                        package: 'Fuel' with: 'Fuel-MartinDias.243';
				package: 'FuelTests' with: 'FuelTests-MarianoMartinezPeck.33';
                        package: 'FuelBenchmarks' with: 'FuelBenchmarks-MartinDias.26';
				package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.8';
				package: 'FuelContainer' with: 'FuelContainer-MartinDias.1';
				package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.3';
				package: 'FuelBenchmarksMC2' with: 'FuelBenchmarksMC2-MartinDias.1' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MartinDias 8/13/2011 05:31'!
version15: spec 
	<version: '1.5' imports: #('1.5-baseline') >

	spec for: #pharo do: [
		spec blessing: #release.
		spec description: '
- Initialize instances after materialization implementing #fuelAfterMaterialization.
- Ignore transient instance variables overriding #fuelIgnoredInstanceVariableNames.
- Limit serialization progress bar to update at most once every 250 milliseconds.
- Traits are serialized and materialized as a regular objects (http://code.google.com/p/fuel/issues/detail?id=59).
- Removed mappers system cache (Eliot).
- Many new tests.
- Benchmarks: compare Fuel against StOMP, SRP, SIXX, Magma, EsAndEm and Fuel with progress bar.
- Benchmarks: new samples, scripts, and CSV exporter.	
- Benchmarks: measure serialization stream size.
- Removed some redundant #fuelAccept:.
- Several aesthetic changes in protocols, categories and comments.
- Now #materialize answers the materialized root.
- Removed special cluster for HashedCollection.Now #rehash is sended via #fuelAfterMaterialization.
- MethodContext serialization does not serialize temps (http://code.google.com/p/fuel/issues/detail?id=61).
- Classes and Traits now serialize its environment (testCreateWithSmalltalkGlobalsEnvironment).
- Fixed serialization of non-octet characters (testCharacter).
- Fixed a bug serializing the system dictionary. FLWellKnownObjectsCluster handles it. (testSmalltalkGlobals).
- Fixed a bug serializing class variables (testClassVariable).
- Fixed a bug when serializing a collection with size greater than 1^16 with repeated elements inside.
- Fixed testTwoCompiledMethodsReferencingSameClassVariable.
- Optimization: instanceIndexes are directly created with the exact size (Henrik).		
		'.
		spec 
			package: 'Fuel' with: 'Fuel-MartinDias.267';
			package: 'FuelTests' with: 'FuelTests-MarianoMartinezPeck.77';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MartinDias.62';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.14';
			package: 'FuelContainer' with: 'FuelContainer-MartinDias.1';
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MarianoMartinezPeck.6';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-mariano.3';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MarianoMartinezPeck.1';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MarianoMartinezPeck.4';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MarianoMartinezPeck.3';
			package: 'FuelLogo' with: 'FuelLogo-MartinDias.2';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.
		spec
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MarianoMartinezPeck 9/24/2011 19:40'!
version161: spec 
	<version: '1.6.1' imports: #('1.6-baseline') >

	spec for: #pharo do: [
		spec blessing: #development.
		spec description: ' . '.
		spec 
			package: 'Fuel' with: 'Fuel-MarianoMartinezPeck.444';
			package: 'FuelTests' with: 'FuelTests-MartinDias.118';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MartinDias.77';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.24';
			package: 'FuelPackageLoader' with: 'FuelPackageLoader-MartinDias.42';
			package: 'FuelPackageLoaderTests' with: 'FuelPackageLoaderTests-MartinDias.3';
			package: 'FuelContainer' with: 'FuelContainer-MarianoMartinezPeck.2';
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MarianoMartinezPeck.6';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-mariano.3';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MarianoMartinezPeck.1';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.7';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MarianoMartinezPeck.3';
			package: 'FuelLogo' with: 'FuelLogo-MartinDias.2';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.
		spec
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MartinDias 8/18/2011 23:30'!
version16: spec 
	<version: '1.6' imports: #('1.5-baseline') >

	spec for: #pharo do: [
		spec blessing: #release.
		spec description: '
This version does not add any new concrete functionality but has two main achievements: a performance improvement and a design clean up.

Many changes included in this release are part of a design clean up. They are a necessary step forward to new functionalities that are coming soon. They make code more understandable. They enable simpler extension. Happily they also helped to improve serialization performance by reducing unnecessary interactions. And is specially important a bottleneck in graph analysis stage we have attacked, obtaining great results.

Details:
 - Removed explicit references to cluster classes scattered around the system. For example, in previous versions Float>>fuelCluster has an explicit reference to FLFloatCluster. This version replaces this by a double dispatch interaction.
 - Clusters: Better reification. Removed annoying IDs. Removed Singleton instance creation machanism, now mappers manage uniqueness in a better way. 
 - Mappers: They were simplified. New mapping machanism inspired on Chain of Responsibility pattern. The global objects detection has been reduced considerably.
 - Analyzer: Part of its behavior and state has been moved to a new abstraction called "clusterization".
'.
		spec 
			package: 'Fuel' with: 'Fuel-MartinDias.338';
			package: 'FuelTests' with: 'FuelTests-MartinDias.84';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MartinDias.68';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.15';
			package: 'FuelContainer' with: 'FuelContainer-MartinDias.1';
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MarianoMartinezPeck.6';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-mariano.3';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MarianoMartinezPeck.1';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MarianoMartinezPeck.4';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MarianoMartinezPeck.3';
			package: 'FuelLogo' with: 'FuelLogo-MartinDias.2';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.
		spec
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MartinDias 10/14/2011 02:51'!
version17: spec 
	<version: '1.7' imports: #('1.7-baseline') >

	spec for: #pharo do: [
		spec blessing: #release.
		spec description: '
The list of changes includes performance optimizations, design clean-ups, and new features.
- The FLSerializer and FLMaterializer API has changed. They are no longer implementing the algorithms but are a kind of Façade.
- Serialization substitutions: "Store this object instead of me."
- Global sends: "Restore me by sending this selector to this global"
- Versioning the stream: We prefix the stream with a version number that should match when loading.
- Performance optimizations on instances of:
 - Word-like classes. (We thank a lot to Henrik Sperre Johansen for your help!!)
 - ByteString and Symbol.
 - Date, Time, Duration and DateAndTime.
 - Point and Rectangle.
 - MethodDictionary. Now materialization is 2000x faster, thanks to its new rehash without become.
- Huge clean-up in Tests package.'.

		spec 
			package: 'Fuel' with: 'Fuel-MartinDias.479';
			package: 'FuelTests' with: 'FuelTests-MartinDias.157';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MartinDias.88';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.27';
			package: 'FuelCompatibilityBeforePharo13' with: 'FuelCompatibilityBeforePharo13-MarianoMartinezPeck.2';
			package: 'FuelPackageLoader' with: 'FuelPackageLoader-MartinDias.43';
			package: 'FuelPackageLoaderTests' with: 'FuelPackageLoaderTests-MartinDias.6';
			package: 'FuelExamples' with: 'FuelExamples-MartinDias.5';
			package: 'FuelContainer' with: 'FuelContainer-MartinDias.3';
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MarianoMartinezPeck.6';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-mariano.3';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MarianoMartinezPeck.1';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.7';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MarianoMartinezPeck.3';
			package: 'FuelLogo' with: 'FuelLogo-MartinDias.2';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.
		spec
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8'		
		].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MarianoMartinezPeck 1/1/2013 19:26'!
version181: spec
	<version: '1.8.1' imports: #('1.8.1-baseline' )>

	spec for: #'squeakCommon' do: [
		spec blessing: #release.
		spec description: '
- same as 1.8
- fix: serialization / materialization of Date objects.
- do not use Pharo compatibility packages for Squeak
- use individual compatibility packages for Squeak
- new compatibility fixes
- supported images: 
	Pharo 1.1.1, 1.1.2, 1.2, 1.3, 1.4, 2.0
	Squeak 4.1, 4.2, 4.3, 4.4'.

		spec 
			package: 'Fuel' with: 'Fuel-MaxLeske.686';
			package: 'FuelTests' with: 'FuelTests-MartinDias.267';
			package: 'FuelDebug' with: 'FuelDebug-MartinDias.8';
			package: 'FuelUtilities' with: 'FuelUtilities-MartinDias.1';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.54';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MartinDias.140';
			package: 'FuelCompression' with: 'FuelCompression-MartinDias.9';
			
			package: 'FuelCompatibilityBeforeSqueak42' with: 'FuelCompatibilityBeforeSqueak42-MaxLeske.1';
			package: 'FuelCompatibilityBeforeSqueak44' with: 'FuelCompatibilityBeforeSqueak44-MaxLeske.4';
			package: 'FuelCompatibilityBeforeSqueak45' with: 'FuelCompatibilityBeforeSqueak45-MaxLeske.3';
			
			package: 'FuelTestsCompatibilityBeforeSqueak42' with: 'FuelTestsCompatibilityBeforeSqueak42-MaxLeske.2';
			package: 'FuelTestsCompatibilityBeforeSqueak44' with: 'FuelTestsCompatibilityBeforeSqueak44-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforeSqueak45' with: 'FuelTestsCompatibilityBeforeSqueak45-MaxLeske.6';
			
			package: 'FuelCompatibilityBeforePharo12' with: 'FuelCompatibilityBeforePharo12-MartinDias.8';
			package: 'FuelCompatibilityBeforePharo13' with: 'FuelCompatibilityBeforePharo13-MarianoMartinezPeck.3';
			package: 'FuelCompatibilityBeforePharo14' with: 'FuelCompatibilityBeforePharo14-MartinDias.3';
			package: 'FuelCompatibilityBeforePharo20' with: 'FuelCompatibilityBeforePharo20-MaxLeske.12';
			package: 'FuelCompatibilityBeforePharo21' with: 'FuelCompatibilityBeforePharo21-MaxLeske.3';
			
			package: 'FuelTestsCompatibilityBeforePharo21' with: 'FuelTestsCompatibilityBeforePharo21-MaxLeske.5' ].

	spec for: #'pharo' do: [
		spec 
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8.3';
			project: 'Roassal' with: '1.0';
			project: 'FileSystem' with: '2.0.4'.
		spec 
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.7';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-MartinDias.4';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MartinDias.2';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.12';
			package: 'FuelBenchmarksSRP' with: 'FuelBenchmarksSRP-MartinDias.4';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MartinDias.4';
			package: 'FuelPackageLoader' with: 'FuelPackageLoader-MarianoMartinezPeck.105';
			package: 'FuelPackageLoaderMetacello' with: 'FuelPackageLoaderMetacello-MarianoMartinezPeck.3';
			package: 'FuelPackageLoaderTests' with: 'FuelPackageLoaderTests-MarianoMartinezPeck.32';
			package: 'FuelPreview' with: 'FuelPreview-MartinDias.10';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MarianoMartinezPeck.50';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MartinDias.43';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'. ].

	spec for: #'pharo2.0.x' do: [
		spec 
			package: 'FuelFileSystem' with: 'FuelFileSystem-PavelKrivanek.4';
			package: 'FuelFileSystemTests' with: 'FuelFileSystemTests-MarianoMartinezPeck.2';
			package: 'FuelCommandLineHandler' with: 'FuelCommandLineHandler-MarianoMartinezPeck.3'. ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MaxLeske 2/19/2013 20:20'!
version182: spec
	<version: '1.8.2' imports: #('1.8.2-baseline' )>

	spec for: #'squeakCommon' do: [
		spec blessing: #release.
		spec description: '
- Date / DateAndTime are now serialized consistently across different images (Squeak and Pharo)
- improvements to compatibility packages
'.

		spec 
			package: 'Fuel' with: 'Fuel-MaxLeske.687';
			package: 'FuelTests' with: 'FuelTests-MartinDias.267';
			package: 'FuelDebug' with: 'FuelDebug-MartinDias.8';
			package: 'FuelUtilities' with: 'FuelUtilities-MartinDias.1';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.54';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MartinDias.140';
			package: 'FuelCompression' with: 'FuelCompression-MartinDias.9';
			
			package: 'FuelCompatibilityBeforeSqueak42' with: 'FuelCompatibilityBeforeSqueak42-MaxLeske.1';
			package: 'FuelCompatibilityBeforeSqueak44' with: 'FuelCompatibilityBeforeSqueak44-MaxLeske.4';
			package: 'FuelCompatibilityBeforeSqueak45' with: 'FuelCompatibilityBeforeSqueak45-MaxLeske.5';
			
			package: 'FuelTestsCompatibilityBeforeSqueak42' with: 'FuelTestsCompatibilityBeforeSqueak42-MaxLeske.2';
			package: 'FuelTestsCompatibilityBeforeSqueak44' with: 'FuelTestsCompatibilityBeforeSqueak44-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforeSqueak45' with: 'FuelTestsCompatibilityBeforeSqueak45-MaxLeske.6';
			
			package: 'FuelCompatibilityBeforePharo12' with: 'FuelCompatibilityBeforePharo12-MaxLeske.9';
			package: 'FuelCompatibilityBeforePharo13' with: 'FuelCompatibilityBeforePharo13-MarianoMartinezPeck.3';
			package: 'FuelCompatibilityBeforePharo14' with: 'FuelCompatibilityBeforePharo14-MartinDias.3';
			package: 'FuelCompatibilityBeforePharo20' with: 'FuelCompatibilityBeforePharo20-MaxLeske.17';
			package: 'FuelCompatibilityBeforePharo21' with: 'FuelCompatibilityBeforePharo21-MaxLeske.5';
			
			package: 'FuelTestsCompatibilityBeforePharo20' with: 'FuelTestsCompatibilityBeforePharo20-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforePharo21' with: 'FuelTestsCompatibilityBeforePharo21-MaxLeske.5' ].

	spec for: #'pharo' do: [
		spec 
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8.3';
			project: 'Roassal' with: '1.0';
			project: 'FileSystem' with: '2.0.4'.
		spec 
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.7';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-MartinDias.4';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MartinDias.2';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.12';
			package: 'FuelBenchmarksSRP' with: 'FuelBenchmarksSRP-MartinDias.4';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MartinDias.4';
			package: 'FuelPackageLoader' with: 'FuelPackageLoader-MarianoMartinezPeck.105';
			package: 'FuelPackageLoaderMetacello' with: 'FuelPackageLoaderMetacello-MarianoMartinezPeck.3';
			package: 'FuelPackageLoaderTests' with: 'FuelPackageLoaderTests-MarianoMartinezPeck.32';
			package: 'FuelPreview' with: 'FuelPreview-MartinDias.10';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MarianoMartinezPeck.50';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MartinDias.43';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'. ].

	spec for: #'pharo2.0.x' do: [
		spec 
			package: 'FuelFileSystem' with: 'FuelFileSystem-PavelKrivanek.4';
			package: 'FuelFileSystemTests' with: 'FuelFileSystemTests-MarianoMartinezPeck.2';
			package: 'FuelCommandLineHandler' with: 'FuelCommandLineHandler-MarianoMartinezPeck.3'. ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MartinDias 5/26/2012 01:47'!
version18: spec
	<version: '1.8' imports: #('1.8-baseline' )>

	spec for: #'squeakCommon' do: [
		spec blessing: #release.
		spec description: '
- Improved API for customizing how graph is traced.
- FuelMetalevel: serialization of stuff like classes and compiled methods  moved to an optional package.
- Customize objects to be treated as globals.
- Migrations: declare at materialization time class and variables renames.
- Weak references properly managed. Thanks to Juan Vuletich and Levente.
- Thanks Pavel for helping us improving FuelPackageLoader with wonderful ideas and bug reports.
- Serialization speed up on large graphs by using specialized collections. Thanks Levente.
- Encoder and Decoder: new reifications that clarify the design. Thanks Colin Putney.
- Optimized serialization of clean BlockClosures, which do not need the whole stack of contexts. Thanks Juan Vuletich and Eliot Miranda.
- Added a clear error hierarchy.
- Debug facilities, including graph visualization using Roassal. Thanks Alexandre and Doru.
- Many more new tests. Including those from extension packages, we have almost 600 tests.
- Repository moved from squeaksource to ss3.'.

		spec 
			package: 'Fuel' with: 'Fuel-MartinDias.685';
			package: 'FuelTests' with: 'FuelTests-MartinDias.267';
			package: 'FuelDebug' with: 'FuelDebug-MartinDias.8';
			package: 'FuelUtilities' with: 'FuelUtilities-MartinDias.1';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.54';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MartinDias.140';
			package: 'FuelCompression' with: 'FuelCompression-MartinDias.9';
			package: 'FuelCompatibilityForSqueak' with: 'FuelCompatibilityForSqueak-MMP.4';
			package: 'FuelCompatibilityBeforePharo12' with: 'FuelCompatibilityBeforePharo12-MartinDias.8';
			package: 'FuelCompatibilityBeforePharo13' with: 'FuelCompatibilityBeforePharo13-MarianoMartinezPeck.3';
			package: 'FuelCompatibilityBeforePharo14' with: 'FuelCompatibilityBeforePharo14-MartinDias.3';
			package: 'FuelCompatibilityBeforePharo20' with: 'FuelCompatibilityBeforePharo20-MartinDias.4'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8.3';
			project: 'Roassal' with: '1.0';
			project: 'FileSystem' with: '2.0.4'.
		spec 
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.7';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-MartinDias.4';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MartinDias.2';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.12';
			package: 'FuelBenchmarksSRP' with: 'FuelBenchmarksSRP-MartinDias.4';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MartinDias.4';
			package: 'FuelPackageLoader' with: 'FuelPackageLoader-MarianoMartinezPeck.105';
			package: 'FuelPackageLoaderMetacello' with: 'FuelPackageLoaderMetacello-MarianoMartinezPeck.3';
			package: 'FuelPackageLoaderTests' with: 'FuelPackageLoaderTests-MarianoMartinezPeck.32';
			package: 'FuelPreview' with: 'FuelPreview-MartinDias.10';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MarianoMartinezPeck.50';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MartinDias.43';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'. ].

	spec for: #'pharo2.0.x' do: [
		spec 
			package: 'FuelFileSystem' with: 'FuelFileSystem-PavelKrivanek.4';
			package: 'FuelFileSystemTests' with: 'FuelFileSystemTests-MarianoMartinezPeck.2';
			package: 'FuelCommandLineHandler' with: 'FuelCommandLineHandler-MarianoMartinezPeck.3'. ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MarianoMartinezPeck 3/31/2012 12:09'!
version18ForMarea: spec 
	<version: '1.8-forMarea' imports: #('1.8-baseline') >

	spec for: #pharo do: [
		spec blessing: #beta.
		spec description: ' just a fixed version for marea paper '.

		spec 
			package: 'Fuel' with: 'Fuel-MarianoMartinezPeck.618';
			package: 'FuelTests' with: 'FuelTests-MarianoMartinezPeck.214';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MartinDias.105';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MarianoMartinezPeck.39';
			package: 'FuelCompatibilityBeforePharo12' with: 'FuelCompatibilityBeforePharo12-MarianoMartinezPeck.6';
			package: 'FuelCompatibilityBeforePharo13' with: 'FuelCompatibilityBeforePharo13-MarianoMartinezPeck.2';
			package: 'FuelCompatibilityBeforePharo14' with: 'FuelCompatibilityBeforePharo14-MarianoMartinezPeck.1';
			package: 'FuelCompatibilityForSqueak' with: 'FuelCompatibilityForSqueak-MMP.4';
			package: 'FuelPackageLoader' with: 'FuelPackageLoader-MarianoMartinezPeck.53';
			package: 'FuelPackageLoaderTests' with: 'FuelPackageLoaderTests-MarianoMartinezPeck.7';
			package: 'FuelExamples' with: 'FuelExamples-MarianoMartinezPeck.8';
			package: 'FuelContainer' with: 'FuelContainer-MartinDias.3';
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MarianoMartinezPeck.6';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-mariano.3';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MarianoMartinezPeck.1';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.7';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MarianoMartinezPeck.3';
			package: 'FuelLogo' with: 'FuelLogo-MartinDias.2';
			package: 'FuelCompression' with: 'FuelCompression-MarianoMartinezPeck.7';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MarianoMartinezPeck.28';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MarianoMartinezPeck.15';
			package: 'FuelPresentations' with: 'FuelPresentations-MartinDias.6';
			package: 'FuelFileSystem' with: 'FuelFileSystem-MarianoMartinezPeck.3';
			package: 'FuelFileSystemTests' with: 'FuelFileSystemTests-MarianoMartinezPeck.1';
			package: 'FuelPreview' with: 'FuelPreview-MartinDias.7';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.
		spec
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8'		


		].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MarianoMartinezPeck 1/19/2012 22:22'!
version18beta1: spec 
	<version: '1.8-beta1' imports: #('1.8-baseline') >

	spec for: #pharo do: [
		spec blessing: #beta.
		spec description: '
		
		== visibles to the user:

- Metalevel serialization (serialization of classes, traits, compiled methods, etc) moved to a separate package FuelMetalevel. This makes Fuel core much smaller and eases the portability to other dialects such as Squeak and VW. It also makes sense, since almost nobody nobody uses "full" serialization for everything.
- Previously methods were completely serialized by default. This includes for example, SortedCollection. Now, by default, methods are serialized as globals. Special treatment for DoIt: all methods by default continue to be considered as global unless they are a #DoIt, in which case it is serialized fully.
- New special cluster for BlockClosures. Now "clean" closures avoid serializing the whole stack of contexts :) Thanks Juan Vuletich and Eliot Miranda.
- Weak references properly managed. Thanks Juan Vuletich and Levente.
- Fixed FLSerializer>>serialize:toFileNamed:. Thank you Norbert Hartl.
- Store index references more efficiently by using less bytes when possible. It means reduction in stream size
- Customize globals. Each user can add objects managed as global. It also lets the user to handle custom singletons.
- Manual migrations: class and variables renames.
- #visitSubstitution:by:
- #visitGlobalSend:name:selector:
- New FuelFileSystem compatibility package. It just adds a few extension methods to FileSystem streams. This way you can use Fuel with FileSystem streams out of the box.
- New package FuelCompression, which is an experiment using a gzip stream. We discover some bugs in the streams, but in addition, some some tests failed and one crash the VM. So, do not consider this a production ready. But if you want to give us a hand…
- New package FuelPreview for visualizating the object graph to serialize. This tool is based on Roassal. Thanks Tudor Girba and Alexander Bergel.
- Official "port to Squeak". With this version, Fuel (only the core) works out of the box in Squeak 4.2 and 4.3.
- This same version Fuel 1.8 can work in Pharo 1.1, 1.2, 1.3, 1.4, Squeak 4.2 and 4.3. You always need to load Fuel with Metacello and it will handle the compatibility packages.
- Fuel code was migrated from http://www.squeaksource.com/Fuel to http://ss3.gemstone.com/ss/Fuel

== not visibles:
- Added new LargeIdentityHashedCollection. This improves up to 20% serialization speed with large graphs. Thanks Levente!!!!!!
- Merged 9 primitive clusters in 1 -> FLHookPrimitiveCluster.
- Rename DefaultMapper -> GeneralMapper
- Some optimization with #to:do:
- Removing streamFactory from both FLSerializer and FLMaterializer. They were not necessary and implementation simplifies a lot in this way.
- Reification of Encoder and Decoder: they delegate in just a few basic methods of a stream, making easy to port. It means Fuel just needs 2 methods for the write stream and 3 from read stream.
- Mappers directly map objects.
- FuelShouldIgnoreFuel.
- Added more and more benchmarks samples and test cases. Test coverage is about 90%.
- No direct access anymore to streams. Everything pass from Encoder and Decoder

		
		
		'.

		spec 
			package: 'Fuel' with: 'Fuel-MarianoMartinezPeck.615';
			package: 'FuelTests' with: 'FuelTests-MarianoMartinezPeck.214';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MartinDias.105';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MarianoMartinezPeck.39';
			package: 'FuelCompatibilityBeforePharo12' with: 'FuelCompatibilityBeforePharo12-MarianoMartinezPeck.6';
			package: 'FuelCompatibilityBeforePharo13' with: 'FuelCompatibilityBeforePharo13-MarianoMartinezPeck.2';
			package: 'FuelCompatibilityBeforePharo14' with: 'FuelCompatibilityBeforePharo14-MarianoMartinezPeck.1';
			package: 'FuelCompatibilityForSqueak' with: 'FuelCompatibilityForSqueak-MMP.4';
			package: 'FuelPackageLoader' with: 'FuelPackageLoader-MartinDias.52';
			package: 'FuelPackageLoaderTests' with: 'FuelPackageLoaderTests-MarianoMartinezPeck.7';
			package: 'FuelExamples' with: 'FuelExamples-MarianoMartinezPeck.8';
			package: 'FuelContainer' with: 'FuelContainer-MartinDias.3';
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MarianoMartinezPeck.6';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-mariano.3';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MarianoMartinezPeck.1';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.7';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MarianoMartinezPeck.3';
			package: 'FuelLogo' with: 'FuelLogo-MartinDias.2';
			package: 'FuelCompression' with: 'FuelCompression-MarianoMartinezPeck.7';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MarianoMartinezPeck.28';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MarianoMartinezPeck.15';
			package: 'FuelPresentations' with: 'FuelPresentations-MartinDias.6';
			package: 'FuelFileSystem' with: 'FuelFileSystem-MarianoMartinezPeck.3';
			package: 'FuelFileSystemTests' with: 'FuelFileSystemTests-MarianoMartinezPeck.1';
			package: 'FuelPreview' with: 'FuelPreview-MartinDias.7';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.
		spec
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8'		


		].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MaxLeske 11/25/2013 06:20'!
version191: spec
	<version: '1.9.1' imports: #('1.9-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '
- (fix) the graph that is serialized is exactly the one found during traversal of the graph. This allows for graphs that inlclude short delays
- (enhancement) #fuelReplacement can be overridden to replace an object or class with another. This method should be quicker than using #visitSubstitution:by:'.
		spec 
			package: 'Fuel' with: 'Fuel-MaxLeske.766';
			package: 'FuelTests' with: 'FuelTests-MaxLeske.315';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MartinDias.71';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MartinDias.59';
			package: 'FuelDebug' with: 'FuelDebug-MartinDias.12';
			package: 'FuelPreview' with: 'FuelPreview-MartinDias.10';
			package: 'FuelUtilities' with: 'FuelUtilities-MartinDias.1';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.62';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MaxLeske.149';
			
			package: 'FuelCompatibilityBeforePharo12' with: 'FuelCompatibilityBeforePharo12-MaxLeske.12';
			package: 'FuelCompatibilityBeforePharo13' with: 'FuelCompatibilityBeforePharo13-MaxLeske.4';
			package: 'FuelCompatibilityBeforePharo14' with: 'FuelCompatibilityBeforePharo14-MartinDias.3';
			package: 'FuelCompatibilityBeforePharo20' with: 'FuelCompatibilityBeforePharo20-MaxLeske.18';
			package: 'FuelCompatibilityBeforePharo21' with: 'FuelCompatibilityBeforePharo21-MaxLeske.5';
			
			package: 'FuelTestsCompatibilityBeforePharo12' with: 'FuelTestsCompatibilityBeforePharo12-MaxLeske.3';
			package: 'FuelTestsCompatibilityBeforePharo20' with: 'FuelTestsCompatibilityBeforePharo20-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforePharo21' with: 'FuelTestsCompatibilityBeforePharo21-MaxLeske.5';
			
			package: 'FuelCompatibilityBeforeSqueak42' with: 'FuelCompatibilityBeforeSqueak42-MaxLeske.2';
			package: 'FuelCompatibilityBeforeSqueak44' with: 'FuelCompatibilityBeforeSqueak44-MaxLeske.4';
			package: 'FuelCompatibilityBeforeSqueak45' with: 'FuelCompatibilityBeforeSqueak45-MaxLeske.7';
			
			package: 'FuelTestsCompatibilityBeforeSqueak42' with: 'FuelTestsCompatibilityBeforeSqueak42-MaxLeske.4';
			package: 'FuelTestsCompatibilityBeforeSqueak43' with: 'FuelTestsCompatibilityBeforeSqueak43-MaxLeske.1';
			package: 'FuelTestsCompatibilityBeforeSqueak44' with: 'FuelTestsCompatibilityBeforeSqueak44-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforeSqueak45' with: 'FuelTestsCompatibilityBeforeSqueak45-MartinDias.8'.

		spec 
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8.3';
			project: 'Roassal' with: '1.61'.

		spec 
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.7';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-MartinDias.4';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MartinDias.2';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.12';
			package: 'FuelBenchmarksSRP' with: 'FuelBenchmarksSRP-MartinDias.4';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MartinDias.4';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.

		spec 
			package: 'FuelCommandLineHandler' with: 'FuelCommandLineHandler-EstebanLorenzano.21';
			package: 'FuelSystem-FileRegistry' with: 'FuelSystem-FileRegistry-EstebanLorenzano.3'; 
			package: 'FuelTools-Debugger' with: 'FuelTools-Debugger-EstebanLorenzano.2' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MaxLeske 11/25/2013 06:20'!
version192: spec
	<version: '1.9.2' imports: #('1.9.2-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: 'development'.
		spec 
			package: 'Fuel' with: 'Fuel-MartinDias.772';
			package: 'FuelTests' with: 'FuelTests-MaxLeske.330';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MartinDias.71';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MartinDias.59';
			package: 'FuelDebug' with: 'FuelDebug-MartinDias.12';
			package: 'FuelPreview' with: 'FuelPreview-MartinDias.10';
			package: 'FuelUtilities' with: 'FuelUtilities-MartinDias.1';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.62';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MaxLeske.149';
			
			package: 'FuelCompatibilityBeforePharo12' with: 'FuelCompatibilityBeforePharo12-MaxLeske.12';
			package: 'FuelCompatibilityBeforePharo13' with: 'FuelCompatibilityBeforePharo13-MaxLeske.4';
			package: 'FuelCompatibilityBeforePharo14' with: 'FuelCompatibilityBeforePharo14-MartinDias.3';
			package: 'FuelCompatibilityBeforePharo20' with: 'FuelCompatibilityBeforePharo20-MaxLeske.18';
			package: 'FuelCompatibilityBeforePharo21' with: 'FuelCompatibilityBeforePharo21-MaxLeske.5';
			
			package: 'FuelTestsCompatibilityBeforePharo12' with: 'FuelTestsCompatibilityBeforePharo12-MaxLeske.3';
			package: 'FuelTestsCompatibilityBeforePharo20' with: 'FuelTestsCompatibilityBeforePharo20-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforePharo21' with: 'FuelTestsCompatibilityBeforePharo21-MaxLeske.5';
			
			package: 'FuelCompatibilityBeforeSqueak42' with: 'FuelCompatibilityBeforeSqueak42-MaxLeske.2';
			package: 'FuelCompatibilityBeforeSqueak44' with: 'FuelCompatibilityBeforeSqueak44-MaxLeske.4';
			package: 'FuelCompatibilityBeforeSqueak45' with: 'FuelCompatibilityBeforeSqueak45-MaxLeske.7';
			
			package: 'FuelTestsCompatibilityBeforeSqueak42' with: 'FuelTestsCompatibilityBeforeSqueak42-MaxLeske.4';
			package: 'FuelTestsCompatibilityBeforeSqueak43' with: 'FuelTestsCompatibilityBeforeSqueak43-MaxLeske.1';
			package: 'FuelTestsCompatibilityBeforeSqueak44' with: 'FuelTestsCompatibilityBeforeSqueak44-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforeSqueak45' with: 'FuelTestsCompatibilityBeforeSqueak45-MartinDias.8'.

		spec 
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8.3';
			project: 'Roassal' with: '1.61'.

		spec 
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.7';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-MartinDias.4';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MartinDias.2';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.12';
			package: 'FuelBenchmarksSRP' with: 'FuelBenchmarksSRP-MartinDias.4';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MartinDias.4';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.

		spec 
			package: 'FuelCommandLineHandler' with: 'FuelCommandLineHandler-EstebanLorenzano.21';
			package: 'FuelSystem-FileRegistry' with: 'FuelSystem-FileRegistry-EstebanLorenzano.3'; 
			package: 'FuelTools-Debugger' with: 'FuelTools-Debugger-EstebanLorenzano.2' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MaxLeske 2/22/2016 21:39'!
version193: spec
	<version: '1.9.3' imports: #('1.9.3-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- (feature) the #fuelReplacement selector offers the ability to statically replace an object (e.g. with nil) during analysis. This can lead to significantly smaller graphs and improved speed when serializing large graphs
- (feature) serialize the same graph that was analyzed instead of retrazing the graph during serialization. This prevents changes in the graph from happening between analysis and serialization
- (change) store source when serializing CompiledMethod objects. Needed because Opal does not allow decompilation
- (fix) migrate variables across hierarchy
- (feature) Object>>serializeToFileNamed: shortcut for serializing arbitrary objects
- (fix) better compression for LargeNegativeIntegers (https://pharo.fogbugz.com/f/cases/12052/Fuel-could-store-LargeNegativeInteger-up-to-32bits-magnitude)'.
		spec 
			package: 'Fuel' with: 'Fuel-MartinDias.791';
			package: 'FuelTests' with: 'FuelTests-MaxLeske.371';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MartinDias.73';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MartinDias.60';
			package: 'FuelDebug' with: 'FuelDebug-MartinDias.12';
			package: 'FuelPreview' with: 'FuelPreview-MartinDias.10';
			package: 'FuelUtilities' with: 'FuelUtilities-MartinDias.1';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.62';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MaxLeske.150';
			
			package: 'FuelCompatibilityBeforePharo12' with: 'FuelCompatibilityBeforePharo12-MaxLeske.12';
			package: 'FuelCompatibilityBeforePharo13' with: 'FuelCompatibilityBeforePharo13-MaxLeske.4';
			package: 'FuelCompatibilityBeforePharo14' with: 'FuelCompatibilityBeforePharo14-MartinDias.3';
			package: 'FuelCompatibilityBeforePharo20' with: 'FuelCompatibilityBeforePharo20-MaxLeske.18';
			package: 'FuelCompatibilityBeforePharo30' with: 'FuelCompatibilityBeforePharo30-MaxLeske.5';
			
			package: 'FuelTestsCompatibilityBeforePharo12' with: 'FuelTestsCompatibilityBeforePharo12-MaxLeske.3';
			package: 'FuelTestsCompatibilityBeforePharo20' with: 'FuelTestsCompatibilityBeforePharo20-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforePharo30' with: 'FuelTestsCompatibilityBeforePharo30-MaxLeske.5';
			
			package: 'FuelCompatibilityBeforeSqueak42' with: 'FuelCompatibilityBeforeSqueak42-MaxLeske.2';
			package: 'FuelCompatibilityBeforeSqueak44' with: 'FuelCompatibilityBeforeSqueak44-MaxLeske.4';
			package: 'FuelCompatibilityBeforeSqueak45' with: 'FuelCompatibilityBeforeSqueak45-MaxLeske.8';
			package: 'FuelCompatibilityBeforeSqueak46' with: 'FuelCompatibilityBeforeSqueak46-MaxLeske.2';
			
			package: 'FuelTestsCompatibilityBeforeSqueak42' with: 'FuelTestsCompatibilityBeforeSqueak42-MaxLeske.4';
			package: 'FuelTestsCompatibilityBeforeSqueak43' with: 'FuelTestsCompatibilityBeforeSqueak43-MaxLeske.1';
			package: 'FuelTestsCompatibilityBeforeSqueak44' with: 'FuelTestsCompatibilityBeforeSqueak44-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforeSqueak45' with: 'FuelTestsCompatibilityBeforeSqueak45-MaxLeske.11';
			package: 'FuelTestsCompatibilityBeforeSqueak46' with: 'FuelTestsCompatibilityBeforeSqueak46-MaxLeske.3'.

		spec 
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8.3';
			project: 'Roassal' with: '1.61'.

		spec 
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.7';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-MartinDias.4';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MartinDias.2';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.12';
			package: 'FuelBenchmarksSRP' with: 'FuelBenchmarksSRP-MartinDias.4';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MartinDias.4';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.

		spec 
			package: 'FuelCommandLineHandler' with: 'FuelCommandLineHandler-MarcusDenker.24';
			package: 'FuelSystem-FileRegistry' with: 'FuelSystem-FileRegistry-EstebanLorenzano.3'; 
			package: 'FuelTools-Debugger' with: 'FuelTools-Debugger-MarcusDenker.9' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MaxLeske 8/22/2015 00:20'!
version194: spec
	<version: '1.9.4' imports: #('1.9.4-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- (fix) Initialize trait category. Change required by Esteban for fixing the CI Monkey (ImageWorker).'.
		spec 
			package: 'Fuel' with: 'Fuel-MaxLeske.800';
			package: 'FuelTests' with: 'FuelTests-MaxLeske.382';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MartinDias.75';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MaxLeske.61';
			package: 'FuelDebug' with: 'FuelDebug-MartinDias.12';
			package: 'FuelPreview' with: 'FuelPreview-MartinDias.13';
			package: 'FuelUtilities' with: 'FuelUtilities-MartinDias.1';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.62';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MaxLeske.150';
			
			package: 'FuelCompatibilityBeforePharo12' with: 'FuelCompatibilityBeforePharo12-MaxLeske.12';
			package: 'FuelCompatibilityBeforePharo13' with: 'FuelCompatibilityBeforePharo13-MaxLeske.4';
			package: 'FuelCompatibilityBeforePharo14' with: 'FuelCompatibilityBeforePharo14-MartinDias.3';
			package: 'FuelCompatibilityBeforePharo20' with: 'FuelCompatibilityBeforePharo20-MaxLeske.18';
			package: 'FuelCompatibilityBeforePharo30' with: 'FuelCompatibilityBeforePharo30-MaxLeske.5';
			package: 'FuelCompatibilityBeforePharo40' with: 'FuelCompatibilityBeforePharo40-MaxLeske.1';
			
			package: 'FuelTestsCompatibilityBeforePharo12' with: 'FuelTestsCompatibilityBeforePharo12-MaxLeske.3';
			package: 'FuelTestsCompatibilityBeforePharo20' with: 'FuelTestsCompatibilityBeforePharo20-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforePharo30' with: 'FuelTestsCompatibilityBeforePharo30-MaxLeske.6';
			
			package: 'FuelCompatibilityBeforeSqueak42' with: 'FuelCompatibilityBeforeSqueak42-MaxLeske.2';
			package: 'FuelCompatibilityBeforeSqueak44' with: 'FuelCompatibilityBeforeSqueak44-MaxLeske.4';
			package: 'FuelCompatibilityBeforeSqueak45' with: 'FuelCompatibilityBeforeSqueak45-MaxLeske.8';
			package: 'FuelCompatibilityBeforeSqueak46' with: 'FuelCompatibilityBeforeSqueak46-MaxLeske.3';
			package: 'FuelCompatibilityBeforeSqueak47' with: 'FuelCompatibilityBeforeSqueak47-MaxLeske.2';
			
			package: 'FuelTestsCompatibilityBeforeSqueak42' with: 'FuelTestsCompatibilityBeforeSqueak42-MaxLeske.4';
			package: 'FuelTestsCompatibilityBeforeSqueak43' with: 'FuelTestsCompatibilityBeforeSqueak43-MaxLeske.1';
			package: 'FuelTestsCompatibilityBeforeSqueak44' with: 'FuelTestsCompatibilityBeforeSqueak44-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforeSqueak45' with: 'FuelTestsCompatibilityBeforeSqueak45-MaxLeske.11';
			package: 'FuelTestsCompatibilityBeforeSqueak46' with: 'FuelTestsCompatibilityBeforeSqueak46-MaxLeske.4';
			package: 'FuelTestsCompatibilityBeforeSqueak47' with: 'FuelTestsCompatibilityBeforeSqueak47-MaxLeske.4'.

		spec 
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8.3';
			project: 'Roassal' with: '1.61'.

		spec 
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.7';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-MartinDias.4';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MartinDias.2';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.12';
			package: 'FuelBenchmarksSRP' with: 'FuelBenchmarksSRP-MartinDias.4';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MartinDias.4';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.

		spec 
			package: 'FuelCommandLineHandler' with: 'FuelCommandLineHandler-MarcusDenker.24';
			package: 'FuelSystem-FileRegistry' with: 'FuelSystem-FileRegistry-EstebanLorenzano.3'; 
			package: 'FuelTools-Debugger' with: 'FuelTools-Debugger-MarcusDenker.9' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MartinDias 3/14/2013 15:52'!
version19: spec
	<version: '1.9' imports: #('1.9-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '
- (feature) Put back FLSerializer>>on: 
- (optimization) added clusters for SmallInteger
- (fix) Date & DateAndTime (thanks Cami and Marcus)
- (optmization) Optimized clusters for most common collections
- (feature) Built-in support for header: 
   - pre and post materialization actions (clean closures)
   - attach additional objects
   - materialize only the header
- (fix) Substitutions are more safe
- (feature) Support Drag&Drop of .fuel files
- (feature) DoIt and not-installed CompiledMethods are serialized by default
- (feature) New hooks #fuelNew and #fuelNew: that can be overriden for custom instantiation
- (feature) Globals:
   - Added #globalEnvironment: to specify where the globals are looked-up
   - A SystemDictionary instance is treated as globals only when it is "Smalltalk globals"
   - Explicit references to "Smalltalk globals" changed to "self class environment"
- (cleanup) Removed an unneeded cluster (FLWellKnownObjectsCluster)'.

		spec 
			package: 'Fuel' with: 'Fuel-EstebanLorenzano.762';
			package: 'FuelTests' with: 'FuelTests-MaxLeske.311';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MartinDias.71';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MartinDias.59';
			package: 'FuelDebug' with: 'FuelDebug-MartinDias.12';
			package: 'FuelPreview' with: 'FuelPreview-MartinDias.10';
			package: 'FuelUtilities' with: 'FuelUtilities-MartinDias.1';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.59';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MartinDias.148';
			
			package: 'FuelCompatibilityBeforePharo12' with: 'FuelCompatibilityBeforePharo12-MaxLeske.10';
			package: 'FuelCompatibilityBeforePharo13' with: 'FuelCompatibilityBeforePharo13-MaxLeske.4';
			package: 'FuelCompatibilityBeforePharo14' with: 'FuelCompatibilityBeforePharo14-MartinDias.3';
			package: 'FuelCompatibilityBeforePharo20' with: 'FuelCompatibilityBeforePharo20-MaxLeske.18';
			package: 'FuelCompatibilityBeforePharo21' with: 'FuelCompatibilityBeforePharo21-MaxLeske.5';
			
			package: 'FuelTestsCompatibilityBeforePharo12' with: 'FuelTestsCompatibilityBeforePharo12-MaxLeske.1';
			package: 'FuelTestsCompatibilityBeforePharo20' with: 'FuelTestsCompatibilityBeforePharo20-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforePharo21' with: 'FuelTestsCompatibilityBeforePharo21-MaxLeske.5';
			
			package: 'FuelCompatibilityBeforeSqueak42' with: 'FuelCompatibilityBeforeSqueak42-MaxLeske.2';
			package: 'FuelCompatibilityBeforeSqueak44' with: 'FuelCompatibilityBeforeSqueak44-MaxLeske.4';
			package: 'FuelCompatibilityBeforeSqueak45' with: 'FuelCompatibilityBeforeSqueak45-MaxLeske.7';
			
			package: 'FuelTestsCompatibilityBeforeSqueak42' with: 'FuelTestsCompatibilityBeforeSqueak42-MaxLeske.4';
			package: 'FuelTestsCompatibilityBeforeSqueak43' with: 'FuelTestsCompatibilityBeforeSqueak43-MaxLeske.1';
			package: 'FuelTestsCompatibilityBeforeSqueak44' with: 'FuelTestsCompatibilityBeforeSqueak44-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforeSqueak45' with: 'FuelTestsCompatibilityBeforeSqueak45-MartinDias.8'.

		spec 
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8.3';
			project: 'Roassal' with: '1.61'.

		spec 
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.7';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-MartinDias.4';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MartinDias.2';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.12';
			package: 'FuelBenchmarksSRP' with: 'FuelBenchmarksSRP-MartinDias.4';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MartinDias.4';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.

		spec 
			package: 'FuelCommandLineHandler' with: 'FuelCommandLineHandler-EstebanLorenzano.21';
			package: 'FuelSystem-FileRegistry' with: 'FuelSystem-FileRegistry-EstebanLorenzano.3'; 
			package: 'FuelTools-Debugger' with: 'FuelTools-Debugger-EstebanLorenzano.2' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MartinDias 3/25/2013 18:21'!
version19AlphaForTanker: spec 
	<version: '1.9-alphaForTanker' imports: #('1.9-alphaForTanker-baseline') >

	spec for: #pharo do: [
		spec blessing: #beta.
		spec description: ' just a fixed version for Tanker'.

		spec 
			package: 'Fuel' with: 'Fuel-MarianoMartinezPeck.718';
			package: 'FuelTests' with: 'FuelTests-MarianoMartinezPeck.286';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MarianoMartinezPeck.60';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MarianoMartinezPeck.46'.

		].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MaxLeske 2/19/2016 17:01'!
version200: spec
	<version: '2.0.0' imports: #('2.0.0-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: 'Prepared for Spur Object Format'.
		spec 
			package: 'Fuel' with: 'Fuel-EstebanLorenzano.819';
			package: 'FuelTests' with: 'FuelTests-EstebanLorenzano.395';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MartinDias.75';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MaxLeske.61';
			package: 'FuelDebug' with: 'FuelDebug-MartinDias.12';
			package: 'FuelPreview' with: 'FuelPreview-MartinDias.13';
			package: 'FuelUtilities' with: 'FuelUtilities-MartinDias.1';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.62';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MaxLeske.150';
			
			package: 'FuelCompatibilityBeforePharo12' with: 'FuelCompatibilityBeforePharo12-MaxLeske.12';
			package: 'FuelCompatibilityBeforePharo13' with: 'FuelCompatibilityBeforePharo13-MaxLeske.4';
			package: 'FuelCompatibilityBeforePharo14' with: 'FuelCompatibilityBeforePharo14-MartinDias.3';
			package: 'FuelCompatibilityBeforePharo20' with: 'FuelCompatibilityBeforePharo20-MaxLeske.18';
			package: 'FuelCompatibilityBeforePharo30' with: 'FuelCompatibilityBeforePharo30-MaxLeske.5';
			package: 'FuelCompatibilityBeforePharo40' with: 'FuelCompatibilityBeforePharo40-MaxLeske.1';
			
			package: 'FuelTestsCompatibilityBeforePharo12' with: 'FuelTestsCompatibilityBeforePharo12-MaxLeske.3';
			package: 'FuelTestsCompatibilityBeforePharo20' with: 'FuelTestsCompatibilityBeforePharo20-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforePharo30' with: 'FuelTestsCompatibilityBeforePharo30-MaxLeske.6';
			
			package: 'FuelCompatibilityBeforeSqueak42' with: 'FuelCompatibilityBeforeSqueak42-MaxLeske.2';
			package: 'FuelCompatibilityBeforeSqueak44' with: 'FuelCompatibilityBeforeSqueak44-MaxLeske.4';
			package: 'FuelCompatibilityBeforeSqueak45' with: 'FuelCompatibilityBeforeSqueak45-MaxLeske.8';
			package: 'FuelCompatibilityBeforeSqueak46' with: 'FuelCompatibilityBeforeSqueak46-MaxLeske.3';
			package: 'FuelCompatibilityBeforeSqueak47' with: 'FuelCompatibilityBeforeSqueak47-MaxLeske.2';
			
			package: 'FuelTestsCompatibilityBeforeSqueak42' with: 'FuelTestsCompatibilityBeforeSqueak42-MaxLeske.4';
			package: 'FuelTestsCompatibilityBeforeSqueak43' with: 'FuelTestsCompatibilityBeforeSqueak43-MaxLeske.1';
			package: 'FuelTestsCompatibilityBeforeSqueak44' with: 'FuelTestsCompatibilityBeforeSqueak44-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforeSqueak45' with: 'FuelTestsCompatibilityBeforeSqueak45-MaxLeske.11';
			package: 'FuelTestsCompatibilityBeforeSqueak46' with: 'FuelTestsCompatibilityBeforeSqueak46-MaxLeske.4';
			package: 'FuelTestsCompatibilityBeforeSqueak47' with: 'FuelTestsCompatibilityBeforeSqueak47-MaxLeske.4'.

		spec 
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8.3';
			project: 'Roassal' with: '1.61'.

		spec 
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.7';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-MartinDias.4';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MartinDias.2';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.12';
			package: 'FuelBenchmarksSRP' with: 'FuelBenchmarksSRP-MartinDias.4';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MartinDias.4';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.

		spec 
			package: 'FuelCommandLineHandler' with: 'FuelCommandLineHandler-MarcusDenker.24';
			package: 'FuelSystem-FileRegistry' with: 'FuelSystem-FileRegistry-EstebanLorenzano.3'; 
			package: 'FuelTools-Debugger' with: 'FuelTools-Debugger-MarcusDenker.9' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'EstebanLorenzano 2/26/2016 12:37'!
version201: spec
	<version: '2.0.1' imports: #('2.0.0-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: 'Prepared for Spur Object Format'.
		spec 
			package: 'Fuel' with: 'Fuel-EstebanLorenzano.819';
			package: 'FuelTests' with: 'FuelTests-EstebanLorenzano.395';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MarianoMartinezPeck.81';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MaxLeske.61';
			package: 'FuelDebug' with: 'FuelDebug-MartinDias.12';
			package: 'FuelPreview' with: 'FuelPreview-MartinDias.13';
			package: 'FuelUtilities' with: 'FuelUtilities-MartinDias.1';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.62';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MaxLeske.150';
			
			package: 'FuelCompatibilityBeforePharo12' with: 'FuelCompatibilityBeforePharo12-MaxLeske.12';
			package: 'FuelCompatibilityBeforePharo13' with: 'FuelCompatibilityBeforePharo13-MaxLeske.4';
			package: 'FuelCompatibilityBeforePharo14' with: 'FuelCompatibilityBeforePharo14-MartinDias.3';
			package: 'FuelCompatibilityBeforePharo20' with: 'FuelCompatibilityBeforePharo20-MaxLeske.18';
			package: 'FuelCompatibilityBeforePharo30' with: 'FuelCompatibilityBeforePharo30-MaxLeske.5';
			package: 'FuelCompatibilityBeforePharo40' with: 'FuelCompatibilityBeforePharo40-MaxLeske.1';
			
			package: 'FuelTestsCompatibilityBeforePharo12' with: 'FuelTestsCompatibilityBeforePharo12-MaxLeske.3';
			package: 'FuelTestsCompatibilityBeforePharo20' with: 'FuelTestsCompatibilityBeforePharo20-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforePharo30' with: 'FuelTestsCompatibilityBeforePharo30-MaxLeske.6';
			
			package: 'FuelCompatibilityBeforeSqueak42' with: 'FuelCompatibilityBeforeSqueak42-MaxLeske.2';
			package: 'FuelCompatibilityBeforeSqueak44' with: 'FuelCompatibilityBeforeSqueak44-MaxLeske.4';
			package: 'FuelCompatibilityBeforeSqueak45' with: 'FuelCompatibilityBeforeSqueak45-MaxLeske.8';
			package: 'FuelCompatibilityBeforeSqueak46' with: 'FuelCompatibilityBeforeSqueak46-MaxLeske.3';
			package: 'FuelCompatibilityBeforeSqueak47' with: 'FuelCompatibilityBeforeSqueak47-MaxLeske.2';
			
			package: 'FuelTestsCompatibilityBeforeSqueak42' with: 'FuelTestsCompatibilityBeforeSqueak42-MaxLeske.4';
			package: 'FuelTestsCompatibilityBeforeSqueak43' with: 'FuelTestsCompatibilityBeforeSqueak43-MaxLeske.1';
			package: 'FuelTestsCompatibilityBeforeSqueak44' with: 'FuelTestsCompatibilityBeforeSqueak44-MaxLeske.5';
			package: 'FuelTestsCompatibilityBeforeSqueak45' with: 'FuelTestsCompatibilityBeforeSqueak45-MaxLeske.11';
			package: 'FuelTestsCompatibilityBeforeSqueak46' with: 'FuelTestsCompatibilityBeforeSqueak46-MaxLeske.4';
			package: 'FuelTestsCompatibilityBeforeSqueak47' with: 'FuelTestsCompatibilityBeforeSqueak47-MaxLeske.4'.

		spec 
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8.3';
			project: 'Roassal' with: '1.61'.

		spec 
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.7';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-MartinDias.4';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MartinDias.2';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.12';
			package: 'FuelBenchmarksSRP' with: 'FuelBenchmarksSRP-MartinDias.4';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MartinDias.4';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.

		spec 
			package: 'FuelCommandLineHandler' with: 'FuelCommandLineHandler-MarcusDenker.24';
			package: 'FuelSystem-FileRegistry' with: 'FuelSystem-FileRegistry-EstebanLorenzano.3'; 
			package: 'FuelTools-Debugger' with: 'FuelTools-Debugger-MarcusDenker.9' ].! !

!ConfigurationOfFuel methodsFor: 'versions' stamp: 'MaxLeske 3/11/2016 17:08'!
version210: spec
	<version: '2.1.0' imports: #('2.1.0-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: 'Moved compatibility logic to FuelPlatform package'.
		spec
			package: 'Fuel' with: 'Fuel-MaxLeske.822';
			package: 'FuelTests' with: 'FuelTests-MaxLeske.404';
			package: 'FuelMetalevel' with: 'FuelMetalevel-MartinDias.83';
			package: 'FuelMetalevelTests' with: 'FuelMetalevelTests-MaxLeske.63';
			package: 'FuelDebug' with: 'FuelDebug-MartinDias.12';
			package: 'FuelPreview' with: 'FuelPreview-MartinDias.13';
			package: 'FuelUtilities' with: 'FuelUtilities-MartinDias.1';
			package: 'FuelProgressUpdate' with: 'FuelProgressUpdate-MartinDias.62';
			package: 'FuelBenchmarks' with: 'FuelBenchmarks-MaxLeske.150'.
			
		spec 
			project: 'MagmaBase' with: '1.0';
			project: 'SIXX' with: '0.3.6';
			project: 'StOMP' with: '1.8.3';
			project: 'Roassal' with: '1.61'.

		spec 
			package: 'FuelBenchmarksMagma' with: 'FuelBenchmarksMagma-MartinDias.7';
			package: 'FuelBenchmarksSIXX' with: 'FuelBenchmarksSIXX-MartinDias.4';
			package: 'FuelBenchmarksStomp' with: 'FuelBenchmarksStomp-MartinDias.2';
			package: 'FuelProgressUpdateBenchmarks' with: 'FuelProgressUpdateBenchmarks-MartinDias.12';
			package: 'FuelBenchmarksSRP' with: 'FuelBenchmarksSRP-MartinDias.4';
			package: 'FuelBenchmarksEsAndEm' with: 'FuelBenchmarksEsAndEm-MartinDias.4';
			package: 'SRP' with: 'SRP-MartinDias.12';
			package: 'EsAndEm' with: 'EsAndEm-cwp.15'.

		spec 
			package: 'FuelCommandLineHandler' with: 'FuelCommandLineHandler-MarcusDenker.24';
			package: 'FuelSystem-FileRegistry' with: 'FuelSystem-FileRegistry-EstebanLorenzano.3'; 
			package: 'FuelTools-Debugger' with: 'FuelTools-Debugger-MarcusDenker.9' ]! !
